from ipaascommon.api_constants import SNOW_CI_CACHE, EM7_DEV_CLASS_CACHE
from ipaascore import parameter_types
from ipaascore.parameters import StepParameter


attribute_mappings_param = StepParameter(
    name="attribute_mappings",
    description="Mapping of attributes from SL1 to ServiceNow",
    required=False,
    default_value={
        "operatingSystem": ["os"],
        "dnsDomain": ["dns_domain"],
        "memory": ["ram"],
        "cpuMake": ["cpu_type"],
        "cpuCount": ["cpu_count"],
        "cpuSpeed": ["cpu_speed"],
        "diskSize": ["disk_space"],
        "serial": ["serial_number"],
        "assetTag": ["asset_tag"],
        "function": ["justification"],
        "status": ["hardware_substatus"],
        "hostname": ["fqdn", "host_name"],
        "warrantyCost": ["cost"],
        "purchaseDate": ["order_date"],
        "warrantyExpirationDate": ["warranty_expiration"],
        "manufacturer_sys_id": ["manufacturer"],
        "model_sys_id": ["model_id"],
        "ip": ["ip_address"],
        "name": ["name"],
        "dateAdded": ["first_discovered"],
        "Description: {{device.device_category}}, Device Class: {{device.device_class}}": [
            "short_description"
        ],
    },
    param_type=parameter_types.MappingParameterStaticOneToMany(
        left_options=[
            "arraySize",
            "assetTag",
            "asset_id",
            "company_sys_id",
            "component_unique_id",
            "cpuCount",
            "cpuMake",
            "cpuSpeed",
            "dateAdded",
            "depreciationMethod",
            "depreciationSchedule",
            "device_category",
            "device_class",
            "diskCount",
            "diskSize",
            "dnsDomain",
            "dnsName",
            "domain_sys_id",
            "firmwareVersion",
            "floor",
            "function",
            "hostId",
            "hostname",
            "ip",
            "location",
            "make",
            "manufacturer_sys_id",
            "memory",
            "model",
            "model_sys_id",
            "name",
            "operatingSystem",
            "org_id",
            "org_name",
            "owner",
            "panel",
            "parent_device",
            "parent_did",
            "plate",
            "punch",
            "purchaseCheck",
            "purchaseCost",
            "purchaseDate",
            "purchaseOrderNumber",
            "rack",
            "region",
            "rfid",
            "room",
            "serial",
            "serviceCheck",
            "serviceCost",
            "serviceDate",
            "serviceDescription",
            "serviceExpirationDate",
            "serviceOrderNumber",
            "servicePolicyNumber",
            "shelf",
            "sl1_id",
            "sl1_url",
            "snow_ci_class",
            "snow_sys_id",
            "status",
            "vitalAssetInformation",
            "vitalServiceInformation",
            "warrantyCheck",
            "warrantyCost",
            "warrantyDate",
            "warrantyDescription",
            "warrantyExpirationDate",
            "warrantyOrderNumber",
            "warrantyPolicyNumber",
            "zone",
        ],
        left_name="SL1 Attribute",
        right_options=[
            "asset_tag",
            "category",
            "comments",
            "cost",
            "cpu_count",
            "cpu_speed",
            "cpu_type",
            "disk_space",
            "dns_domain",
            "fqdn",
            "hardware_substatus",
            "justification",
            "order_date",
            "os",
            "ram",
            "serial",
            "serial_number",
            "virtual",
            "warranty_expiration",
        ],
        right_name="To ServiceNow Attribute",
        custom=True,
    ),
)

attribs_snow_to_sl_param = StepParameter(
    name=attribute_mappings_param.name,
    description=attribute_mappings_param.description,
    required=attribute_mappings_param.required,
    default_value={
        "operatingSystem": ["os"],
        "dnsDomain": ["dns_domain"],
        "memory": ["ram"],
        "cpuMake": ["cpu_type"],
        "cpuCount": ["cpu_count"],
        "cpuSpeed": ["cpu_speed"],
        "diskSize": ["disk_space"],
        "serial": ["serial_number"],
        "assetTag": ["asset_tag"],
        "function": ["justification"],
        "status": ["hardware_substatus"],
        "hostname": ["fqdn", "host_name"],
        "warrantyCost": ["cost"],
        "purchaseDate": ["order_date"],
        "warrantyExpirationDate": ["warranty_expiration"],
        "make": ["manufacturer_label"],
        "model": ["model_id_label"],
    },
    param_type=parameter_types.MappingParameterStaticOneToMany(
        left_options=[
            "arraySize",
            "assetTag",
            "cpuCount",
            "cpuMake",
            "cpuSpeed",
            "depreciationMethod",
            "depreciationSchedule",
            "diskCount",
            "diskSize",
            "dnsDomain",
            "dnsName",
            "firmwareVersion",
            "floor",
            "function",
            "hostId",
            "hostname",
            "location",
            "make",
            "memory",
            "model",
            "operatingSystem",
            "owner",
            "panel",
            "plate",
            "punch",
            "purchaseCheck",
            "purchaseCost",
            "purchaseDate",
            "purchaseOrderNumber",
            "rack",
            "region",
            "rfid",
            "room",
            "serial",
            "serviceCheck",
            "serviceCost",
            "serviceDate",
            "serviceDescription",
            "serviceExpirationDate",
            "serviceOrderNumber",
            "servicePolicyNumber",
            "shelf",
            "status",
            "warrantyCheck",
            "warrantyCost",
            "warrantyDate",
            "warrantyDescription",
            "warrantyExpirationDate",
            "warrantyOrderNumber",
            "warrantyPolicyNumber",
            "zone",
        ],
        left_name="SL1 Attribute",
        right_options=[
            "asset_tag",
            "category",
            "comments",
            "cost",
            "cpu_count",
            "cpu_speed",
            "cpu_type",
            "disk_space",
            "dns_domain",
            "fqdn",
            "hardware_substatus",
            "justification",
            "order_date",
            "os",
            "ram",
            "serial",
            "serial_number",
            "virtual",
            "warranty_expiration",
        ],
        right_name="To ServiceNow Attribute",
        custom=True,
    ),
)

mappings_param = StepParameter(
    name="mappings",
    default_value={
        "cmdb_ci_computer": ["IBM | IBM OS/400 V5R1M0"],
        "cmdb_ci_esx_resource_pool": ["VMware | Resource Pool"],
        "cmdb_ci_esx_server": [
            "VMWare | ESXi 5.1 w/HR",
            "VMware | Host Server",
            "VMware | ESX(i) 4.0",
            "VMware | ESX(i) w/HR",
            "VMWare | ESX(i) 4.0 w/HR",
            "VMWare | ESX(i)",
            "VMWare | ESX(i) 4.1 w/HR",
            "VMWare | ESXi 5.1 w/HR",
            "VMWare | ESXi 5.0 w/HR",
            "VMware | ESX(i) 4.1",
            "VMware | ESXi 5.1",
            "VMware | ESXi 5.0",
        ],
        "cmdb_ci_ip_firewall": [
            "Check Point Software | OEM",
            "Cisco Systems | 5520 SY",
            "Cisco Systems | ASA 5510",
            "Cisco Systems | ASA 5510-SC",
            "Cisco Systems | ASA 5512-SY",
            "Cisco Systems | ASA 5515-SC",
            "Cisco Systems | ASA 5520-SC",
            "Cisco Systems | ASA 5540-SC",
            "Cisco Systems | ASA 5545",
            "Cisco Systems | ASA 5550",
            "Cisco Systems | ASA 5550-SC",
            "Cisco Systems | ASA 5555-SY",
            "Cisco Systems | ASA 5580",
            "Cisco Systems | ASA 5585S-SP-60",
            "Cisco Systems | IPS SSM-20",
            "Cisco Systems | PIX 501",
            "Cisco Systems | PIX 506",
            "Cisco Systems | PIX 506E",
            "Cisco Systems | PIX 515",
            "Cisco Systems | PIX 515E",
            "Cisco Systems | PIX 515E MSC",
            "Cisco Systems | PIX 520",
            "Cisco Systems | PIX 525",
            "Cisco Systems | PIX 525 SC",
            "Cisco Systems | PIX 535",
            "Cisco Systems | PIX Firewall",
            "Fortinet | FortiGate 200B",
            "Juniper Networks | Netscreen SSG 20",
            "Juniper Networks | Netscreen SSG 320",
            "Juniper Networks | Netscreen SSG 350",
            "Juniper Networks | Netscreen SSG 5 ISDN",
            "Juniper Networks | Netscreen SSG 5 Serial WLAN",
            "Juniper Networks | Netscreen SSG 520",
            "Juniper Networks | SRX220 Firewall",
            "Juniper Networks | SRX550 Firewall",
        ],
        "cmdb_ci_ip_router": [
            "3Com | 3Com Router",
            "3Com | NetBuilder",
            "3Com | NetBuilder Token Ring",
            "3Com | Superstack II, Netbuilder 327 (t",
            "3Com | SW/NBDPE-EW",
            "Altiga Networks | 3002 hardware VPN client",
            "Altiga Networks | Cisco Systems Inc. VPN 3000",
            "Blue Coat | Packeteer PacketShaper 4.0.4",
            "Blue Coat | Packeteer PacketShaper 5.1.1",
            "Blue Coat | Packeteer PacketShaper 7.2.1",
            "Blue Coat | Packetshaper 4.1.0",
            "Blue Coat | PacketShaper 5.2",
            "BlueArc | BlueArc Titan Silicon Server",
            "CacheFlow | 3000 Proxy",
            "CacheFlow | CacheFlow 6000, CacheOS Version:",
            "CacheFlow | OEM",
            "Case Communications | OEM",
            "Cayman GatorSystem | Ether<->Appletalk bridge",
            "Cayman GatorSystem | OEM",
            "Cisco Systems | 1000",
            "Cisco Systems | 10005 ESR",
            "Cisco Systems | 10008 ESR",
            "Cisco Systems | 1003",
            "Cisco Systems | 1004",
            "Cisco Systems | 1005",
            "Cisco Systems | 1020",
            "Cisco Systems | 10400",
            "Cisco Systems | 10720",
            "Cisco Systems | 12004",
            "Cisco Systems | 12006",
            "Cisco Systems | 12008",
            "Cisco Systems | 12010",
            "Cisco Systems | 12012",
            "Cisco Systems | 12016",
            "Cisco Systems | 12404 GSR",
            "Cisco Systems | 12406",
            "Cisco Systems | 12410 GSR",
            "Cisco Systems | 12416",
            "Cisco Systems | 1250",
            "Cisco Systems | 12810",
            "Cisco Systems | 12816",
            "Cisco Systems | 1401",
            "Cisco Systems | 1407",
            "Cisco Systems | 1417",
            "Cisco Systems | 1601",
            "Cisco Systems | 1602",
            "Cisco Systems | 1603",
            "Cisco Systems | 1604",
            "Cisco Systems | 1605",
            "Cisco Systems | 1701",
            "Cisco Systems | 1710",
            "Cisco Systems | 1711",
            "Cisco Systems | 1712",
            "Cisco Systems | 1718",
            "Cisco Systems | 1720",
            "Cisco Systems | 1721",
            "Cisco Systems | 1750",
            "Cisco Systems | 1751",
            "Cisco Systems | 1760",
            "Cisco Systems | 1801 ISR G1",
            "Cisco Systems | 1801M ISR G1",
            "Cisco Systems | 1802 ISR G1",
            "Cisco Systems | 1803 ISR G1",
            "Cisco Systems | 1805 ISR G1",
            "Cisco Systems | 1811 ISR G1",
            "Cisco Systems | 1812 ISR G1",
            "Cisco Systems | 1841 ISR G1",
            "Cisco Systems | 1841ve ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861 ISR G1",
            "Cisco Systems | 1861E ISR G1",
            "Cisco Systems | 1861E ISR G1",
            "Cisco Systems | 1861E ISR G1",
            "Cisco Systems | 1861E ISR G1",
            "Cisco Systems | 1861E ISR G1",
            "Cisco Systems | 1921 ISR G2",
            "Cisco Systems | 1941 ISR G2",
            "Cisco Systems | 1941W-A-K9",
            "Cisco Systems | 1941W-C-K9",
            "Cisco Systems | 1941W-E-K9",
            "Cisco Systems | 1941W-I-K9",
            "Cisco Systems | 1941W-N-K9",
            "Cisco Systems | 1941W-P-K9",
            "Cisco Systems | 1941W-T-K9",
            "Cisco Systems | 2000",
            "Cisco Systems | 2102",
            "Cisco Systems | 2202",
            "Cisco Systems | 2500",
            "Cisco Systems | 2501",
            "Cisco Systems | 2501FRAD-FX",
            "Cisco Systems | 2501LANFRAD-FX",
            "Cisco Systems | 2502",
            "Cisco Systems | 2502LF",
            "Cisco Systems | 2503",
            "Cisco Systems | 2504",
            "Cisco Systems | 2505",
            "Cisco Systems | 2506",
            "Cisco Systems | 2507",
            "Cisco Systems | 2508",
            "Cisco Systems | 2509",
            "Cisco Systems | 2509RJ",
            "Cisco Systems | 2510",
            "Cisco Systems | 2511",
            "Cisco Systems | 2511RJ",
            "Cisco Systems | 2512",
            "Cisco Systems | 2513",
            "Cisco Systems | 2514",
            "Cisco Systems | 2515",
            "Cisco Systems | 2516",
            "Cisco Systems | 2517",
            "Cisco Systems | 2518",
            "Cisco Systems | 2519",
            "Cisco Systems | 2520",
            "Cisco Systems | 2521",
            "Cisco Systems | 2522",
            "Cisco Systems | 2523",
            "Cisco Systems | 2524",
            "Cisco Systems | 2525",
            "Cisco Systems | 2610",
            "Cisco Systems | 2610-M",
            "Cisco Systems | 2610XM",
            "Cisco Systems | 2611",
            "Cisco Systems | 2611-M",
            "Cisco Systems | 2611XM",
            "Cisco Systems | 2612",
            "Cisco Systems | 2613",
            "Cisco Systems | 2620",
            "Cisco Systems | 2620XM",
            "Cisco Systems | 2621",
            "Cisco Systems | 2650",
            "Cisco Systems | 2650XM",
            "Cisco Systems | 2651",
            "Cisco Systems | 2651XM",
            "Cisco Systems | 2691",
            "Cisco Systems | 2801 ISR G1",
            "Cisco Systems | 2801C-K9 ISR G1",
            "Cisco Systems | 2811",
            "Cisco Systems | 2811CK9  ISR G1",
            "Cisco Systems | 2811ve ISR G1",
            "Cisco Systems | 2821 ISR G1",
            "Cisco Systems | 2821C-K9 ISR G1",
            "Cisco Systems | 2851 ISR G1",
            "Cisco Systems | 2851C-K9 ISR G1",
            "Cisco Systems | 2901 ISR G2",
            "Cisco Systems | 2911 ISR G2",
            "Cisco Systems | 2921 ISR G2",
            "Cisco Systems | 2951 ISR G2",
            "Cisco Systems | 3000",
            "Cisco Systems | 3101",
            "Cisco Systems | 3102",
            "Cisco Systems | 3103",
            "Cisco Systems | 3104",
            "Cisco Systems | 3116",
            "Cisco Systems | 316C",
            "Cisco Systems | 316T",
            "Cisco Systems | 3202",
            "Cisco Systems | 3204",
            "Cisco Systems | 3220",
            "Cisco Systems | 3251",
            "Cisco Systems | 3620 ISR",
            "Cisco Systems | 3631",
            "Cisco Systems | 3640 ISR",
            "Cisco Systems | 3660 ISR",
            "Cisco Systems | 3661AC",
            "Cisco Systems | 3661DC",
            "Cisco Systems | 3662AC-CO",
            "Cisco Systems | 3662DC",
            "Cisco Systems | 3662DC-CO",
            "Cisco Systems | 3725 ISR",
            "Cisco Systems | 3745 ISR",
            "Cisco Systems | 3825 ISR G1",
            "Cisco Systems | 3825-NOVPN ISR G1",
            "Cisco Systems | 3825C-K9 ISR G1",
            "Cisco Systems | 3825Cnv-K9 ISR G1",
            "Cisco Systems | 3845 ISR G1",
            "Cisco Systems | 3845-NOVPN ISR G1",
            "Cisco Systems | 3845C-K9 ISR G1",
            "Cisco Systems | 3845Cnv-K9 ISR G1",
            "Cisco Systems | 3925 ISR G2",
            "Cisco Systems | 3925-SPE-250 ISR G1",
            "Cisco Systems | 3925E ISR G2",
            "Cisco Systems | 3945 ISR G2",
            "Cisco Systems | 3945-SPE-200 ISR G2",
            "Cisco Systems | 3945E ISR G2",
            "Cisco Systems | 4000",
            "Cisco Systems | 4224",
            "Cisco Systems | 4321 ISR",
            "Cisco Systems | 4331 ISR",
            "Cisco Systems | 4351 ISR",
            "Cisco Systems | 4431 ISR",
            "Cisco Systems | 4451 ISR",
            "Cisco Systems | 4500",
            "Cisco Systems | 4700",
            "Cisco Systems | 5550 SY",
            "Cisco Systems | 5720",
            "Cisco Systems | 5740",
            "Cisco Systems | 5750",
            "Cisco Systems | 626",
            "Cisco Systems | 6400NRP",
            "Cisco Systems | 673",
            "Cisco Systems | 677 (C3550),",
            "Cisco Systems | 677i",
            "Cisco Systems | 678",
            "Cisco Systems | 7000",
            "Cisco Systems | 7010",
            "Cisco Systems | 7120-4T1",
            "Cisco Systems | 7120-AE3",
            "Cisco Systems | 7120-AT3",
            "Cisco Systems | 7120-E3",
            "Cisco Systems | 7120-SMI3",
            "Cisco Systems | 7120-T3",
            "Cisco Systems | 7140-2AE3",
            "Cisco Systems | 7140-2AT3",
            "Cisco Systems | 7140-2E3",
            "Cisco Systems | 7140-2FE",
            "Cisco Systems | 7140-2MM3",
            "Cisco Systems | 7140-2T3",
            "Cisco Systems | 7140-8T1",
            "Cisco Systems | 7150-2FE",
            "Cisco Systems | 7150-2T3",
            "Cisco Systems | 7150-8T",
            "Cisco Systems | 7201",
            "Cisco Systems | 7202",
            "Cisco Systems | 7204",
            "Cisco Systems | 7204VXR",
            "Cisco Systems | 7206",
            "Cisco Systems | 7206VXR",
            "Cisco Systems | 7301",
            "Cisco Systems | 7304",
            "Cisco Systems | 7400",
            "Cisco Systems | 7401",
            "Cisco Systems | 741",
            "Cisco Systems | 742",
            "Cisco Systems | 743",
            "Cisco Systems | 744",
            "Cisco Systems | 7505",
            "Cisco Systems | 7506",
            "Cisco Systems | 7507",
            "Cisco Systems | 7507MX",
            "Cisco Systems | 7507Z",
            "Cisco Systems | 751",
            "Cisco Systems | 7513",
            "Cisco Systems | 7513MX",
            "Cisco Systems | 7513Z",
            "Cisco Systems | 752",
            "Cisco Systems | 753",
            "Cisco Systems | 7576",
            "Cisco Systems | 7600Seb",
            "Cisco Systems | 7603",
            "Cisco Systems | 7603",
            "Cisco Systems | 7603S",
            "Cisco Systems | 7604",
            "Cisco Systems | 7606",
            "Cisco Systems | 7606",
            "Cisco Systems | 7606S",
            "Cisco Systems | 7609",
            "Cisco Systems | 7609 IOS",
            "Cisco Systems | 7609S",
            "Cisco Systems | 761",
            "Cisco Systems | 7613",
            "Cisco Systems | 7613 IOS",
            "Cisco Systems | 7613s",
            "Cisco Systems | 762",
            "Cisco Systems | 765",
            "Cisco Systems | 766",
            "Cisco Systems | 771",
            "Cisco Systems | 772",
            "Cisco Systems | 775",
            "Cisco Systems | 776",
            "Cisco Systems | 801",
            "Cisco Systems | 802",
            "Cisco Systems | 802J",
            "Cisco Systems | 803",
            "Cisco Systems | 804",
            "Cisco Systems | 804J",
            "Cisco Systems | 805",
            "Cisco Systems | 806",
            "Cisco Systems | 811",
            "Cisco Systems | 8110",
            "Cisco Systems | 813",
            "Cisco Systems | 815",
            "Cisco Systems | 826",
            "Cisco Systems | 826 Quad V",
            "Cisco Systems | 827",
            "Cisco Systems | 827-4V",
            "Cisco Systems | 827-H",
            "Cisco Systems | 828",
            "Cisco Systems | 831",
            "Cisco Systems | 836",
            "Cisco Systems | 837",
            "Cisco Systems | 851 ISR G1",
            "Cisco Systems | 8540 Wireless Controller",
            "Cisco Systems | 857 ISR G1",
            "Cisco Systems | 860 AP",
            "Cisco Systems | 861 ISR G2",
            "Cisco Systems | 866",
            "Cisco Systems | 867 ISR  G1",
            "Cisco Systems | 867-VAE ISR",
            "Cisco Systems | 867-VAE K9 ISR",
            "Cisco Systems | 871 ISR G1",
            "Cisco Systems | 876 ISR G1",
            "Cisco Systems | 877 ISR G1",
            "Cisco Systems | 877M ISR G1",
            "Cisco Systems | 878 ISR G1",
            "Cisco Systems | 880 AP",
            "Cisco Systems | 881 ISR G2",
            "Cisco Systems | 881 K9 ISR",
            "Cisco Systems | 881-G-7 K9 ISR",
            "Cisco Systems | 881-G-B K9 ISR",
            "Cisco Systems | 881-G-S K9 ISR",
            "Cisco Systems | 881-G-U K9 ISR",
            "Cisco Systems | 881-G-V K9 ISR",
            "Cisco Systems | 881-V K9 ISR",
            "Cisco Systems | 881-WE-K9 ISR",
            "Cisco Systems | 881-WP-K9 ISR",
            "Cisco Systems | 881G ISR G2",
            "Cisco Systems | 881SRST ISR G2",
            "Cisco Systems | 881W-DA-K9 ISR",
            "Cisco Systems | 881W-DE-K9 ISR",
            "Cisco Systems | 885-D ISR G1",
            "Cisco Systems | 885-E ISR G1",
            "Cisco Systems | 886 ISR G1",
            "Cisco Systems | 886G ISR G1",
            "Cisco Systems | 886SRST ISR G1",
            "Cisco Systems | 886VA ISR G2",
            "Cisco Systems | 887 ISR G1",
            "Cisco Systems | 887G ISR G1",
            "Cisco Systems | 887M ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 887V ISR G2",
            "Cisco Systems | 888 ISR G2",
            "Cisco Systems | 888G ISR G2",
            "Cisco Systems | 888SRST ISR G2",
            "Cisco Systems | 890 AP",
            "Cisco Systems | 891 ISR G2",
            "Cisco Systems | 892 ISR G2",
            "Cisco Systems | 892-FSP K9 ISR",
            "Cisco Systems | 892F",
            "Cisco Systems | Access Pro EC",
            "Cisco Systems | Access Pro RC",
            "Cisco Systems | AIR CT5520",
            "Cisco Systems | AP 1100",
            "Cisco Systems | AP 1210",
            "Cisco Systems | AP 350",
            "Cisco Systems | AS5200",
            "Cisco Systems | AS5300",
            "Cisco Systems | AS5350",
            "Cisco Systems | AS5400",
            "Cisco Systems | AS5800",
            "Cisco Systems | AS5850",
            "Cisco Systems | ASA 5505",
            "Cisco Systems | ASA 5505 W",
            "Cisco Systems | ASA 5512-K7",
            "Cisco Systems | ASA 5512-K7-SY",
            "Cisco Systems | ASA 5515",
            "Cisco Systems | ASA 5515-K7",
            "Cisco Systems | ASA 5515-K7-SC",
            "Cisco Systems | ASA 5520",
            "Cisco Systems | ASA 5540",
            "Cisco Systems | ASA 5545-K7",
            "Cisco Systems | ASA 5545-SC",
            "Cisco Systems | ASA 5580-SC",
            "Cisco Systems | ASA 5585 NM-20X-1GE",
            "Cisco Systems | ASA 5585 NM-4X-10GE",
            "Cisco Systems | ASA 5585 SSP-10-K7-SC",
            "Cisco Systems | ASA 5585 SSP-10-K7-SY",
            "Cisco Systems | ASA 5585 SSP-10-SY",
            "Cisco Systems | ASA 5585 SSP-20-K7-SC",
            "Cisco Systems | ASA 5585 SSP-40-K7-SC",
            "Cisco Systems | ASA 5585 SSP-40-K7-SY",
            "Cisco Systems | ASA 5585 SSP-60-K7-SC",
            "Cisco Systems | ASA 5585 SSP-60-K7-SY",
            "Cisco Systems | ASA 5585 SSSP-LPS10-K7",
            "Cisco Systems | ASA 5585 SSSP-LPS40-K7",
            "Cisco Systems | ASA 5585 SSSP-LPS40-Virtual",
            "Cisco Systems | ASA 5585S-SP-10-K7",
            "Cisco Systems | ASA 5585S-SP-20",
            "Cisco Systems | ASA 5585S-SP-40",
            "Cisco Systems | ASA 5585S-SP-60-K7",
            "Cisco Systems | ASA 5585S-SP-60-SC",
            "Cisco Systems | ASA SM1 sc",
            "Cisco Systems | ASA SSP-IPS40-K9",
            "Cisco Systems | ASA SSP-IPS60-K9",
            "Cisco Systems | ASR 1001",
            "Cisco Systems | ASR 1001-X",
            "Cisco Systems | ASR 1002",
            "Cisco Systems | ASR 1002-F",
            "Cisco Systems | ASR 1002-X",
            "Cisco Systems | ASR 1002-XC",
            "Cisco Systems | ASR 1004",
            "Cisco Systems | ASR 1006",
            "Cisco Systems | ASR 1009-X",
            "Cisco Systems | ASR 1013",
            "Cisco Systems | ASR 9001",
            "Cisco Systems | ASR 9006",
            "Cisco Systems | ASR 901",
            "Cisco Systems | ASR 901-TenGig-AC",
            "Cisco Systems | ASR 901-TenGig-ACE",
            "Cisco Systems | ASR 901-TenGig-DC",
            "Cisco Systems | ASR 901-TenGig-DCE",
            "Cisco Systems | ASR 9010",
            "Cisco Systems | ASR 901E",
            "Cisco Systems | ASR 902",
            "Cisco Systems | ASR 903",
            "Cisco Systems | ASR 9912",
            "Cisco Systems | ASR 9922",
            "Cisco Systems | C3000",
            "Cisco Systems | C3271MARC-TP",
            "Cisco Systems | C3271MARC-TP",
            "Cisco Systems | C881W ISR G2",
            "Cisco Systems | C887VSRST",
            "Cisco Systems | C888ESRST",
            "Cisco Systems | Catalyst 1900i",
            "Cisco Systems | Catalyst 3011",
            "Cisco Systems | Catalyst 3750-48",
            "Cisco Systems | Catalyst 3750E-48TD",
            "Cisco Systems | Catalyst 3750G-24PS",
            "Cisco Systems | Catalyst 3750G-24TS-1U",
            "Cisco Systems | Catalyst 3750X-24",
            "Cisco Systems | Catalyst 3750X-24P",
            "Cisco Systems | Catalyst 3750X-48",
            "Cisco Systems | Catalyst 3750X-48P",
            "Cisco Systems | Catalyst 8510",
            "Cisco Systems | Catalyst 8515",
            "Cisco Systems | Catalyst WS-F6K-MSFC",
            "Cisco Systems | Catalyst WS-F6K-MSFC2",
            "Cisco Systems | CGR 2010",
            "Cisco Systems | Cisco 819G-4G-A-K9",
            "Cisco Systems | Cisco 819G-4G-G-K9",
            "Cisco Systems | Cisco 819G-4G-GA-K9",
            "Cisco Systems | Cisco 819G-4G-V-K9",
            "Cisco Systems | Cisco 819G-7-A-K9",
            "Cisco Systems | Cisco 819G-7-K9",
            "Cisco Systems | Cisco 819G-B-K9",
            "Cisco Systems | Cisco 819G-BM-K9",
            "Cisco Systems | Cisco 819G-LTE-MNA-K9",
            "Cisco Systems | Cisco 819G-S-K9",
            "Cisco Systems | Cisco 819G-SM-K9",
            "Cisco Systems | Cisco 819G-U-K9",
            "Cisco Systems | Cisco 819G-UM-K9",
            "Cisco Systems | Cisco 819G-V-K9",
            "Cisco Systems | Cisco 819G-VM-K9",
            "Cisco Systems | Cisco 819G7-AM-K9",
            "Cisco Systems | Cisco 819G7-M-K9",
            "Cisco Systems | Cisco 819GW-LTE-GAE-K9",
            "Cisco Systems | Cisco 819GW-LTE-MNA-A-K9",
            "Cisco Systems | Cisco 819H-K9",
            "Cisco Systems | Cisco 819HG-4G-A-K9",
            "Cisco Systems | Cisco 819HG-4G-G-K9",
            "Cisco Systems | Cisco 819HG-7-A-K9",
            "Cisco Systems | Cisco 819HG-7-A-M-K9",
            "Cisco Systems | Cisco 819HG-7-K9",
            "Cisco Systems | Cisco 819HG-7-M-K9",
            "Cisco Systems | Cisco 819HG-B-K9",
            "Cisco Systems | Cisco 819HG-BM-K9",
            "Cisco Systems | Cisco 819HG-S-K9",
            "Cisco Systems | Cisco 819HG-SM-K9",
            "Cisco Systems | Cisco 819HG-U-K9",
            "Cisco Systems | Cisco 819HG-UM-K9",
            "Cisco Systems | Cisco 819HG-V-K9",
            "Cisco Systems | Cisco 819HG-VM-K9",
            "Cisco Systems | Cisco 819HGW-7-A-A-K9",
            "Cisco Systems | Cisco 819HGW-7-E-K9",
            "Cisco Systems | Cisco 819HGW-7-N-K9",
            "Cisco Systems | Cisco 819HGW-S-A-K9",
            "Cisco Systems | Cisco 819HGW-V-A-K9",
            "Cisco Systems | Cisco 819HWD-A-K9",
            "Cisco Systems | Cisco 819HWD-C-K9",
            "Cisco Systems | Cisco 819HWD-E-K9",
            "Cisco Systems | CISCO887VG",
            "Cisco Systems | CR 4430",
            "Cisco Systems | CR 4450",
            "Cisco Systems | CRS 8S Enhanced",
            "Cisco Systems | CRS-1 16S",
            "Cisco Systems | CRS-1 24S FCC",
            "Cisco Systems | CRS-1 4S",
            "Cisco Systems | CSR 1000V",
            "Cisco Systems | DWCE",
            "Cisco Systems | ESR 5915RA",
            "Cisco Systems | ESR 5915RC",
            "Cisco Systems | ESR 5940RA",
            "Cisco Systems | ESR 5940RC",
            "Cisco Systems | Gateway Server",
            "Cisco Systems | GRWIC-D-ES-2S-8PC",
            "Cisco Systems | GRWIC-D-ES-6S",
            "Cisco Systems | GSS 4400",
            "Cisco Systems | IAD 2430-24FXS",
            "Cisco Systems | IAD 2431-16FXS",
            "Cisco Systems | IAD 2431-8FXS",
            "Cisco Systems | IAD 2431-T1/E1",
            "Cisco Systems | IAD 2432-24FXS",
            "Cisco Systems | IAD881B",
            "Cisco Systems | IAD881F",
            "Cisco Systems | IAD886B",
            "Cisco Systems | IAD887B",
            "Cisco Systems | IAD888B",
            "Cisco Systems | IAD888EB-K9",
            "Cisco Systems | IAD888EF-K9",
            "Cisco Systems | ICS 7750",
            "Cisco Systems | IDS 4240 Sensor",
            "Cisco Systems | IGESM",
            "Cisco Systems | IGS",
            "Cisco Systems | ISC 7750-MRP",
            "Cisco Systems | ISC 7750-SPE",
            "Cisco Systems | ISC 7750-SSP",
            "Cisco Systems | ISR 1841-CK9",
            "Cisco Systems | ISR 4400",
            "Cisco Systems | ISR 4441",
            "Cisco Systems | ISR 4442",
            "Cisco Systems | ISR 4452",
            "Cisco Systems | ISR 812G+7-K9",
            "Cisco Systems | ISR 812G- CIFI-SA-K9",
            "Cisco Systems | ISR 812G-CIFI+7-E-K9",
            "Cisco Systems | ISR 812G-CIFI+7-N-K9",
            "Cisco Systems | ISR 812G-CIFI-VA-K9",
            "Cisco Systems | ISR 819(H)G-4G-V-K9",
            "Cisco Systems | ISR 819G-4G-NA-K9",
            "Cisco Systems | ISR 841M-4X-K9",
            "Cisco Systems | ISR 841M-8X-K9",
            "Cisco Systems | ISR 866VAE",
            "Cisco Systems | ISR 866VAE-K9",
            "Cisco Systems | ISR 867VA",
            "Cisco Systems | ISR 881G+7-A-K9",
            "Cisco Systems | ISR 881G2",
            "Cisco Systems | ISR 881GW+7-A-K9",
            "Cisco Systems | ISR 886VA-K9",
            "Cisco Systems | ISR 886VAG+7-K9",
            "Cisco Systems | ISR 886VAWE-K9",
            "Cisco Systems | ISR 887SRST",
            "Cisco Systems | ISR 888E/888EW",
            "Cisco Systems | ISR 888EA",
            "Cisco Systems | ISR 888EG",
            "Cisco Systems | ISR 888EG+7-K9",
            "Cisco Systems | ISR 891-24X-K9",
            "Cisco Systems | ISR 891FWA-K9",
            "Cisco Systems | ISR 896VA-K9",
            "Cisco Systems | ISR 897VA-K9",
            "Cisco Systems | ISR 897VAB-K9",
            "Cisco Systems | ISR 897VAG-LTE-GA-K9",
            "Cisco Systems | ISR 897VAM-K9",
            "Cisco Systems | ISR 897VAM-K9",
            "Cisco Systems | ISR 897VAWA-K9",
            "Cisco Systems | ISR 897VAWE-K9",
            "Cisco Systems | ISR 898EA-K9",
            "Cisco Systems | ISR 899G-LTE-JP-K9",
            "Cisco Systems | ISR C888-K9",
            "Cisco Systems | ISR C891F-K9",
            "Cisco Systems | ISR-WLCNM",
            "Cisco Systems | MC3810",
            "Cisco Systems | MWR 1941-DC",
            "Cisco Systems | MWR 1941-DC-A",
            "Cisco Systems | MWR-2941-DC",
            "Cisco Systems | MWR-2941-DCA",
            "Cisco Systems | MWR1900",
            "Cisco Systems | NAM",
            "Cisco Systems | NME-X-23ES-1G-P",
            "Cisco Systems | ONS 15454 M6",
            "Cisco Systems | PIX 515 SC",
            "Cisco Systems | PIX 515 SY",
            "Cisco Systems | PIX 535 SC",
            "Cisco Systems | PIX 535 SY",
            "Cisco Systems | Pro 2506",
            "Cisco Systems | Pro 2508",
            "Cisco Systems | Pro1003",
            "Cisco Systems | Pro1004",
            "Cisco Systems | Pro1005",
            "Cisco Systems | Pro1020",
            "Cisco Systems | Pro1601",
            "Cisco Systems | Pro1602",
            "Cisco Systems | Pro1603",
            "Cisco Systems | Pro1604",
            "Cisco Systems | Pro2500PCE",
            "Cisco Systems | Pro2501",
            "Cisco Systems | Pro2502",
            "Cisco Systems | Pro2503",
            "Cisco Systems | Pro2504",
            "Cisco Systems | Pro2505",
            "Cisco Systems | Pro2507",
            "Cisco Systems | Pro2509",
            "Cisco Systems | Pro2510",
            "Cisco Systems | Pro2511",
            "Cisco Systems | Pro2512",
            "Cisco Systems | Pro2513",
            "Cisco Systems | Pro2514",
            "Cisco Systems | Pro2515",
            "Cisco Systems | Pro2516",
            "Cisco Systems | Pro2517",
            "Cisco Systems | Pro2518",
            "Cisco Systems | Pro2519",
            "Cisco Systems | Pro2520",
            "Cisco Systems | Pro2521",
            "Cisco Systems | Pro2522",
            "Cisco Systems | Pro2523",
            "Cisco Systems | Pro2524",
            "Cisco Systems | Pro2525",
            "Cisco Systems | Pro3620",
            "Cisco Systems | Pro3640",
            "Cisco Systems | Pro4500",
            "Cisco Systems | Pro4700",
            "Cisco Systems | Pro741",
            "Cisco Systems | Pro742",
            "Cisco Systems | Pro743",
            "Cisco Systems | Pro744",
            "Cisco Systems | Pro751",
            "Cisco Systems | Pro752",
            "Cisco Systems | Pro753",
            "Cisco Systems | Pro761",
            "Cisco Systems | Pro762",
            "Cisco Systems | Pro765",
            "Cisco Systems | Pro766",
            "Cisco Systems | Pro771",
            "Cisco Systems | Pro772",
            "Cisco Systems | Pro775",
            "Cisco Systems | Probe 7301",
            "Cisco Systems | Probe6030",
            "Cisco Systems | Probe6050",
            "Cisco Systems | Probe6070",
            "Cisco Systems | Probe7102",
            "Cisco Systems | Probe7203",
            "Cisco Systems | Probe7223",
            "Cisco Systems | Probe7400",
            "Cisco Systems | Probe7401",
            "Cisco Systems | Probe7501",
            "Cisco Systems | Probe7503",
            "Cisco Systems | Probe8110",
            "Cisco Systems | Probe8241",
            "Cisco Systems | Probe8281",
            "Cisco Systems | Probe8700",
            "Cisco Systems | Probe8702",
            "Cisco Systems | Probe8704",
            "Cisco Systems | Probe8714",
            "Cisco Systems | Probe8724",
            "Cisco Systems | Probe8812",
            "Cisco Systems | Probe8822",
            "Cisco Systems | Probe8911",
            "Cisco Systems | Probe8912",
            "Cisco Systems | Protocol Translator",
            "Cisco Systems | RPM",
            "Cisco Systems | RPM-PR",
            "Cisco Systems | RPM-XF",
            "Cisco Systems | SB 101",
            "Cisco Systems | SB 106",
            "Cisco Systems | SB 107",
            "Cisco Systems | SC3640",
            "Cisco Systems | Serial ISR 1905",
            "Cisco Systems | SM SRE-910-K9",
            "Cisco Systems | SN-5420",
            "Cisco Systems | SN-5428",
            "Cisco Systems | SOHO 71",
            "Cisco Systems | SOHO 76",
            "Cisco Systems | SOHO 77",
            "Cisco Systems | SOHO 77H",
            "Cisco Systems | SOHO 78",
            "Cisco Systems | SOHO 91",
            "Cisco Systems | SOHO 96",
            "Cisco Systems | SOHO 97",
            "Cisco Systems | SPA OC48-POS-SFP",
            "Cisco Systems | TelePresence C or CE Series",
            "Cisco Systems | TelePresence Codec C20",
            "Cisco Systems | TelePresence Codec C40",
            "Cisco Systems | TelePresence Codec C60",
            "Cisco Systems | TelePresence Codec C90",
            "Cisco Systems | TelePresence MX200",
            "Cisco Systems | TelePresence MX200 G2",
            "Cisco Systems | TelePresence MX300",
            "Cisco Systems | TelePresence MX300 G2",
            "Cisco Systems | TelePresence MX700",
            "Cisco Systems | TelePresence MX800",
            "Cisco Systems | TelePresence Profile 42",
            "Cisco Systems | TelePresence Profile 52/55",
            "Cisco Systems | TelePresence Profile 65",
            "Cisco Systems | TelePresence SX10 Quick Set",
            "Cisco Systems | TelePresence SX20 Quick Set",
            "Cisco Systems | TelePresence SX80 Codec",
            "Cisco Systems | TelePresence System T3 Center",
            "Cisco Systems | TelePresence System T3 LR",
            "Cisco Systems | Trouter",
            "Cisco Systems | UBR 10012",
            "Cisco Systems | UBR 7100",
            "Cisco Systems | UBR 7111",
            "Cisco Systems | UBR 7111E",
            "Cisco Systems | UBR 7114",
            "Cisco Systems | UBR 7114E",
            "Cisco Systems | UBR 7223",
            "Cisco Systems | UBR 7225 VXR",
            "Cisco Systems | UBR 7246",
            "Cisco Systems | UBR 7246VXR",
            "Cisco Systems | UBR 904",
            "Cisco Systems | UBR 905",
            "Cisco Systems | UBR 912C",
            "Cisco Systems | UBR 912S",
            "Cisco Systems | UBR 914",
            "Cisco Systems | UBR 924",
            "Cisco Systems | UBR 925",
            "Cisco Systems | URM",
            "Cisco Systems | URM2FE",
            "Cisco Systems | URM2FE2V",
            "Cisco Systems | VG 224",
            "Cisco Systems | VPN 3002",
            "Cisco Systems | WAE 7326-K9",
            "Cisco Systems | WAE 7371-K9",
            "Cisco Systems | WAE-512",
            "Cisco Systems | WAE-612",
            "Cisco Systems | WAVE 274-K9",
            "Cisco Systems | WAVE 294-K9",
            "Cisco Systems | WAVE 474-K9",
            "Cisco Systems | WAVE 594-K9",
            "Cisco Systems | Webex DX70",
            "Cisco Systems | Webex DX80",
            "Cisco Systems | Webex Room 55",
            "Cisco Systems | Webex Room 70 Dual",
            "Cisco Systems | Webex Room 70 Single",
            "Cisco Systems | Webex Room Kit",
            "Cisco Systems | Webex Room Kit Plus",
            "Cisco Systems | WS-SVC-NAM-1",
            "Cisco Systems | WSX 3011",
            "Cray Communications A/S | Express Router 9100",
            "Cray Communications A/S | OEM",
            "DEC | 300 (90TL also)",
            "Develcon | OEM",
            "Digi International | OEM",
            "Digi International | PortServer TS 16",
            "Efficient Networks, Inc. | Efficient Networks 5200",
            "Efficient Networks, Inc. | OEM",
            "Engage Communication | OEM",
            "Foundry Networks | Big IRON 15000",
            "Foundry Networks | Big IRON 4000",
            "Foundry Networks | Big IRON 8000",
            "Foundry Networks | Foundry Networks, Inc. FES4802,",
            "Foundry Networks | Foundry Networks, Inc. NetIron",
            "HanA Systems, Inc. | OEM",
            "HP | HP-UX IA-64",
            "HP | Router",
            "HP | Router 210",
            "HP | Router 230",
            "HP | Router 245",
            "HP | Router 430",
            "HP | Router 445",
            "HP | Router 480",
            "HP | Router PRa",
            "HUAWEI Technology CoLtd | HUA WEI CORP. SNMP",
            "HUAWEI Technology CoLtd | OEM",
            "IBM | 2210-12E Multiprotocol Routing S",
            "IBM | PowerPC or RISC System",
            "Infinite Networks, Ltd. | NAUTICA 200",
            "Intel Corporation | Express 8100 Router",
            "Intel Corporation | Express 8210 Router",
            "Juniper Networks | ERX-1440",
            "Juniper Networks | J2300 Router",
            "Juniper Networks | J2320 Router",
            "Juniper Networks | J2350 Router",
            "Juniper Networks | J4300 Router",
            "Juniper Networks | J4320 Router",
            "Juniper Networks | J4350 Router",
            "Juniper Networks | J6300 Router",
            "Juniper Networks | J6350 Router",
            "Juniper Networks | JCS",
            "Juniper Networks | Juniper m10 Internet Router",
            "Juniper Networks | Juniper m20 Internet Router",
            "Juniper Networks | M10i Router",
            "Juniper Networks | M120 Router",
            "Juniper Networks | M160 Router",
            "Juniper Networks | M320 Router",
            "Juniper Networks | M40 Router",
            "Juniper Networks | M40e Router",
            "Juniper Networks | M5 Router",
            "Juniper Networks | M7i Router",
            "Juniper Networks | MX10 Router",
            "Juniper Networks | MX104 Router",
            "Juniper Networks | MX240 Router",
            "Juniper Networks | MX480 Router",
            "Juniper Networks | MX5 Router",
            "Juniper Networks | MX80 Router",
            "Juniper Networks | MX960 Router",
            "Juniper Networks | Netscreen ISG 1000",
            "Juniper Networks | Netscreen SSG 140",
            "Juniper Networks | Netscreen SSG 20 WLAN",
            "Juniper Networks | Netscreen SSG 5",
            "Juniper Networks | Netscreen SSG 5 ISDN WLAN",
            "Juniper Networks | Netscreen SSG 5 v92",
            "Juniper Networks | Netscreen SSG 550",
            "Juniper Networks | OEM",
            "Juniper Networks | SRX100 Firewall",
            "Juniper Networks | SRX1400 Firewall",
            "Juniper Networks | SRX240 Firewall",
            "Juniper Networks | SRX3400 Firewall",
            "Juniper Networks | SRX3600 Firewall",
            "Juniper Networks | SRX5600 Firewall",
            "Juniper Networks | SRX5800 Firewall",
            "Juniper Networks | T1600 Router",
            "Juniper Networks | T320 Router",
            "Juniper Networks | T640 Router",
            "Juniper Networks | TX Matrix Router",
            "KarlNet | Access Point Base Station",
            "KarlNet | OEM",
            "McAfee | McAfee",
            "Netopia | 4541",
            "Netopia | 4652",
            "Netopia | Netopia (R3100, R45xx, R7xx0, R9",
            "Netopia | Netopia 655-U/POTS",
            "Netopia | Netopia R3100 (v4.10 and up",
            "Netopia | Netopia R6100",
            "Netopia | OEM",
            "Netopia | R5100 serial router",
            "Netopia | R5320",
            "Netopia | R7200-T",
            "Netopia | R910",
            "NetScout Systems | Ethernet probe ml-mr-ns1-ep",
            "NetScout Systems | packet probe 3210",
            "NetScout Systems | Probe3220",
            "NetScout Systems | Probe5020",
            "NetScout Systems | Probe6030",
            "NetScout Systems | Probe6050",
            "NetScout Systems | Probe6070",
            "NetScout Systems | Probe7102",
            "NetScout Systems | Probe7203",
            "NetScout Systems | Probe7223",
            "NetScout Systems | Probe7400",
            "NetScout Systems | Probe7401",
            "NetScout Systems | Probe7501",
            "NetScout Systems | Probe7503",
            "NetScout Systems | Probe8110",
            "NetScout Systems | Probe8241",
            "NetScout Systems | Probe8281",
            "NetScout Systems | Probe8700",
            "NetScout Systems | Probe8702",
            "NetScout Systems | Probe8704",
            "NetScout Systems | Probe8714",
            "NetScout Systems | Probe8724",
            "NetScout Systems | Probe8812",
            "NetScout Systems | Probe8822",
            "NetScout Systems | Probe8911",
            "NetScout Systems | Probe8912",
            "No Wires Needed B.V. | OEM",
            "Nokia | IP 100",
            "Nokia | IP 120",
            "Nokia | IP 300",
            "Nokia | IP 650",
            "Presticom | OEM",
            "Redback Networks | SMS 1000",
            "RedCreek Communications | Ravlin 3200",
            "RiverDelta Networks | OEM",
            "Skyline Technology, Inc. | Kentrox Pacesetter T1/SOHO",
            "Skyline Technology, Inc. | OEM",
            "SonicWALL, Inc. | Pro200/300/VX firewall",
            "TIBCO Inc. | OEM",
            "Wellfleet | IP router",
            "Xedia Corporation | Access Point 300 (version 3?)",
            "Xedia Corporation | Access Point 300_ST v2.0",
            "Xedia Corporation | Access Point 450 v2.0",
            "Xedia Corporation | OEM",
            "YAMAHA Corporation Tsuneyuki | OEM",
        ],
        "cmdb_ci_ip_switch": [
            "3Com | 3Com SuperStack 3 Switch",
            "3Com | 3Com Switch 3824",
            "3Com | 4005 Switch",
            "3Com | 42xx series switch (also Superst",
            "3Com | CELLplex 7000",
            "3Com | CoreBuilder-9000 Enterprise Mana",
            "3Com | ECS",
            "3Com | FMS (FMS v2.0)",
            "3Com | FMS (FMS-Boom)",
            "3Com | FMS (FMS-II)",
            "3Com | FMS (TP8i)",
            "3Com | FMS LinkSwitch",
            "3Com | LANplex2500",
            "3Com | LinkBuilder 3GH",
            "3Com | LinkSwitch 2200",
            "3Com | LinkSwitch 2500",
            "3Com | LinkSwitch 2700",
            "3Com | LinkSwitch1000",
            "3Com | MSH",
            "3Com | MSH LinkSwitch",
            "3Com | PathBuilder S400 Switch",
            "3Com | STARTEK RMON",
            "3Com | SW/NBOCF-RW,11.3",
            "3Com | SW/NBPB500-PS",
            "3Com | SuperStack 3 Switch 4300",
            "3Com | SuperStack II",
            "3Com | SuperStack II Hub (Lanplex 2500",
            "3Com | SuperStack II Hub PS Hub",
            "3Com | SuperStack II Switch",
            "3Com | SuperStack II Switch 3900-24",
            "3Com | SuperStack II Switch 9300",
            "3Com | SuperStack II Switch L3 Module",
            "3Com | SuperStack II/3",
            "3Com | SuperStackII Desktop Switch",
            "3Com | Superstack 3 switch 4400",
            "3Com | Superstack 3 switch 49X0",
            "3Com | Superstack II Switch 9000 SX",
            "3Com | superstackII Switch 3000",
            "Adtran | T3SU-300 CSU/DSU",
            "Adtran | TDU-120e Multiplexer",
            "Agere Systems, Inc. | AP-2000v2.3.3(615) SN-02UT515600",
            "Alcatel | 7700 Switch",
            "Alcatel | 7800 Switch",
            "Allied Telesis | AT-8326GB",
            "Allied Telesis | AT-S24 version 1.1",
            "Allied Telesis | Allied Telesis FastEthernet Swit",
            "Allied Telesis | OEM",
            "Alteon Networks | ACEdirector 3",
            "Alteon Networks | ACEswitch 180",
            "Alteon Networks | ACEswitch 180e",
            "Alteon Networks | Web App 2424-SSL",
            "Altiga Networks | OEM",
            "Arista Networks | DCS-7010T-48",
            "Arista Networks | DCS-7048T-4S",
            "Arista Networks | DCS-7048T-A",
            "Arista Networks | DCS-7050QX-32S",
            "Arista Networks | DCS-7050S-52",
            "Arista Networks | DCS-7050S-64",
            "Arista Networks | DCS-7050SX-64",
            "Arista Networks | DCS-7050SX-96",
            "Arista Networks | DCS-7050SX-96-SSD",
            "Arista Networks | DCS-7120T-4S",
            "Arista Networks | DCS-7124S",
            "Arista Networks | DCS-7124SX",
            "Arista Networks | DCS-7140T-8S",
            "Arista Networks | DCS-7148S",
            "Arista Networks | DCS-7148SX",
            "Arista Networks | DCS-7150S-24",
            "Arista Networks | DCS-7280SE-64",
            "Arista Networks | DCS-7504",
            "Arista Networks | DCS-7508",
            "Asante Technology | OEM",
            "Avaya | IP Phone",
            "Avocent | OEM",
            "Axis Communications | 560 Network Printer Server",
            "Axis Communications | OEM",
            "Blue Coat | OEM",
            "Blue Coat | PacketShaper",
            "Brocade | Channel-AL Switch",
            "Brocade | Fibre Channel Switch.",
            "Brocade | OEM",
            "Campus-REX, | OEM",
            "Cisco Systems | 116C",
            "Cisco Systems | 116T",
            "Cisco Systems | 1220",
            "Cisco Systems | 1220C",
            "Cisco Systems | 1220i",
            "Cisco Systems | 1538M",
            "Cisco Systems | 1548M",
            "Cisco Systems | 1730-LAD16-FXS",
            "Cisco Systems | 1730-LAD8-FXS",
            "Cisco Systems | 1900 AP",
            "Cisco Systems | 2106",
            "Cisco Systems | 2621XM",
            "Cisco Systems | 2911T-K9 ISR G2",
            "Cisco Systems | 3200 Wireless MIC",
            "Cisco Systems | 3205 Wireless MIC",
            "Cisco Systems | 3500 Wireless Controller",
            "Cisco Systems | 3662AC",
            "Cisco Systems | 3710-98-HP001",
            "Cisco Systems | 520 Wireless Controller",
            "Cisco Systems | 5760 Wireless Controller",
            "Cisco Systems | 6015 IP DSL",
            "Cisco Systems | 6100",
            "Cisco Systems | 6130",
            "Cisco Systems | 6160 IP DSL",
            "Cisco Systems | 6260 IP DSL",
            "Cisco Systems | 627",
            "Cisco Systems | 633",
            "Cisco Systems | 6400-NSP",
            "Cisco Systems | 675",
            "Cisco Systems | 675e",
            "Cisco Systems | 676",
            "Cisco Systems | 7160",
            "Cisco Systems | 801 AGN",
            "Cisco Systems | 801 GN",
            "Cisco Systems | 8400 Stratacom",
            "Cisco Systems | 867-VAE-W-A K9 ISR",
            "Cisco Systems | 867-VAE-W-E K9 ISR",
            "Cisco Systems | 886VA-W ISR G2",
            "Cisco Systems | 9004",
            "Cisco Systems | ACI Controller",
            "Cisco Systems | AGS+",
            "Cisco Systems | AIM2-CUE",
            "Cisco Systems | AIP-SSM-10 Virtual Sensor",
            "Cisco Systems | AIR CT 8510",
            "Cisco Systems | AIR CT5508",
            "Cisco Systems | AIR CT7510",
            "Cisco Systems | AIR-CT2504-K9",
            "Cisco Systems | AP 1200-IOS",
            "Cisco Systems | AP340",
            "Cisco Systems | AP350",
            "Cisco Systems | AS 5350XM",
            "Cisco Systems | AS 5400XM",
            "Cisco Systems | ASA 1000V SC",
            "Cisco Systems | ASA 1000V SY",
            "Cisco Systems | ASA 5506",
            "Cisco Systems | ASA 5506 H",
            "Cisco Systems | ASA 5506 HSY",
            "Cisco Systems | ASA 5506 HTD",
            "Cisco Systems | ASA 5506 W",
            "Cisco Systems | ASA 5506 WSC",
            "Cisco Systems | ASA 5506 WSY",
            "Cisco Systems | ASA 5506 WTD",
            "Cisco Systems | ASA 5506-K7",
            "Cisco Systems | ASA 5506-K7-sc",
            "Cisco Systems | ASA 5506-sy",
            "Cisco Systems | ASA 5508",
            "Cisco Systems | ASA 5508 K7",
            "Cisco Systems | ASA 5508 K7 SC",
            "Cisco Systems | ASA 5508 SY",
            "Cisco Systems | ASA 5510 SY",
            "Cisco Systems | ASA 5512",
            "Cisco Systems | ASA 5512 TD",
            "Cisco Systems | ASA 5512-K7-SC",
            "Cisco Systems | ASA 5512-SC",
            "Cisco Systems | ASA 5515-K7-SY",
            "Cisco Systems | ASA 5515-SY",
            "Cisco Systems | ASA 5516",
            "Cisco Systems | ASA 5516 SC",
            "Cisco Systems | ASA 5525",
            "Cisco Systems | ASA 5525 TD",
            "Cisco Systems | ASA 5525-K7",
            "Cisco Systems | ASA 5525-K7-SC",
            "Cisco Systems | ASA 5525-K7-SY",
            "Cisco Systems | ASA 5525-SC",
            "Cisco Systems | ASA 5525-SY",
            "Cisco Systems | ASA 5540 SY",
            "Cisco Systems | ASA 5545 TD",
            "Cisco Systems | ASA 5545-K7-SC",
            "Cisco Systems | ASA 5545-SY",
            "Cisco Systems | ASA 5555",
            "Cisco Systems | ASA 5555 TD",
            "Cisco Systems | ASA 5555-K7",
            "Cisco Systems | ASA 5555-K7-SC",
            "Cisco Systems | ASA 5555-K7-SY",
            "Cisco Systems | ASA 5555-SC",
            "Cisco Systems | ASA 5580 SY",
            "Cisco Systems | ASA 5585 NM-8X-10GE",
            "Cisco Systems | ASA 5585 SSP-20-K7-SY",
            "Cisco Systems | ASA 5585 SSP-20-SY",
            "Cisco Systems | ASA 5585 SSP-40-SY",
            "Cisco Systems | ASA 5585 SSP-60-SY",
            "Cisco Systems | ASA 5585 SSSP-LPS10-Virtual",
            "Cisco Systems | ASA 5585 SSSP-LPS20-K7",
            "Cisco Systems | ASA 5585 SSSP-LPS20-Virtual",
            "Cisco Systems | ASA 5585 SSSP-LPS60-K7",
            "Cisco Systems | ASA 5585 SSSP-LPS60-Virtual",
            "Cisco Systems | ASA 5585S-SP-10",
            "Cisco Systems | ASA 5585S-SP-10-SC",
            "Cisco Systems | ASA 5585S-SP-20-K7",
            "Cisco Systems | ASA 5585S-SP-20-SC",
            "Cisco Systems | ASA 5585S-SP-40-K7",
            "Cisco Systems | ASA 5585S-SP-40-SC",
            "Cisco Systems | ASA SM1",
            "Cisco Systems | ASA SM1 sy",
            "Cisco Systems | ASA SSP-IPS10-K9",
            "Cisco Systems | ASA SSP-IPS20-K9",
            "Cisco Systems | ASAv",
            "Cisco Systems | ASR 901-10GS-AC",
            "Cisco Systems | ASR 901-10GS-DC",
            "Cisco Systems | ASR 901S-2SG-F-D",
            "Cisco Systems | ASR 901S-3SG-F-D",
            "Cisco Systems | ASR 920-12CZ-A",
            "Cisco Systems | ASR 920-24SZ-IM",
            "Cisco Systems | ASR 920-24SZ-M",
            "Cisco Systems | ASR 920-8SZ-0A",
            "Cisco Systems | ASR 920-8SZ-0D",
            "Cisco Systems | ASR5500",
            "Cisco Systems | Adapter Card",
            "Cisco Systems | BPX 8620",
            "Cisco Systems | BPX 8650",
            "Cisco Systems | BPX SES",
            "Cisco Systems | BR 1410",
            "Cisco Systems | BR 1430",
            "Cisco Systems | CD SCDE 300",
            "Cisco Systems | CDM-4630",
            "Cisco Systems | CE 2636",
            "Cisco Systems | CE 501",
            "Cisco Systems | CE 507",
            "Cisco Systems | CE 511",
            "Cisco Systems | CE 560",
            "Cisco Systems | CE 565",
            "Cisco Systems | CE 590",
            "Cisco Systems | CE 612",
            "Cisco Systems | CE 7305",
            "Cisco Systems | CE 7306",
            "Cisco Systems | CE 7326",
            "Cisco Systems | CE 7371",
            "Cisco Systems | CGS-2520-16S-8PC",
            "Cisco Systems | CGS-2520-24TC",
            "Cisco Systems | CIMC",
            "Cisco Systems | CPW 1420",
            "Cisco Systems | CPW 1600",
            "Cisco Systems | CPW 1601",
            "Cisco Systems | CPW 1800",
            "Cisco Systems | CPW 1900",
            "Cisco Systems | CRS 16S Enhanced",
            "Cisco Systems | CRS-1 8S",
            "Cisco Systems | CSS 11050",
            "Cisco Systems | CSS 11100",
            "Cisco Systems | CSS 11150",
            "Cisco Systems | CSS 11501",
            "Cisco Systems | CSS 11503",
            "Cisco Systems | CSS 11506",
            "Cisco Systems | CSS 11800",
            "Cisco Systems | CU500",
            "Cisco Systems | CUCM Server",
            "Cisco Systems | CVA122",
            "Cisco Systems | CVA122E",
            "Cisco Systems | CVA124",
            "Cisco Systems | Catalyst  WS-C3650-24PDM",
            "Cisco Systems | Catalyst 1116",
            "Cisco Systems | Catalyst 1200",
            "Cisco Systems | Catalyst 1900C",
            "Cisco Systems | Catalyst 1912C",
            "Cisco Systems | Catalyst 1924",
            "Cisco Systems | Catalyst 2200",
            "Cisco Systems | Catalyst 2350",
            "Cisco Systems | Catalyst 2360-48TD-S",
            "Cisco Systems | Catalyst 2600",
            "Cisco Systems | Catalyst 2828",
            "Cisco Systems | Catalyst 2900",
            "Cisco Systems | Catalyst 2908XL",
            "Cisco Systems | Catalyst 2912-LRE-XL",
            "Cisco Systems | Catalyst 2912MF-XL",
            "Cisco Systems | Catalyst 2912XL",
            "Cisco Systems | Catalyst 2916M-XL",
            "Cisco Systems | Catalyst 2918-24-TC",
            "Cisco Systems | Catalyst 2918-24TT",
            "Cisco Systems | Catalyst 2918-48-TC",
            "Cisco Systems | Catalyst 2918-48-TT",
            "Cisco Systems | Catalyst 2924C-XL",
            "Cisco Systems | Catalyst 2924C-XL-V",
            "Cisco Systems | Catalyst 2924LRE-XL",
            "Cisco Systems | Catalyst 2924M-XL",
            "Cisco Systems | Catalyst 2924XL",
            "Cisco Systems | Catalyst 2924XL-V",
            "Cisco Systems | Catalyst 2926",
            "Cisco Systems | Catalyst 2928-24-LT-C",
            "Cisco Systems | Catalyst 2928-24-TC-C",
            "Cisco Systems | Catalyst 2928-48-TC-C",
            "Cisco Systems | Catalyst 2940-8TF",
            "Cisco Systems | Catalyst 2940-8TT",
            "Cisco Systems | Catalyst 2948G",
            "Cisco Systems | Catalyst 2948G-GE-TX",
            "Cisco Systems | Catalyst 2948G-L3",
            "Cisco Systems | Catalyst 2948G-L3-DC",
            "Cisco Systems | Catalyst 2950-12",
            "Cisco Systems | Catalyst 2950-24",
            "Cisco Systems | Catalyst 2950-24S",
            "Cisco Systems | Catalyst 2950-48-SX",
            "Cisco Systems | Catalyst 2950-48-T",
            "Cisco Systems | Catalyst 2950-G-24-LRE",
            "Cisco Systems | Catalyst 2950-ST-24-LRE",
            "Cisco Systems | Catalyst 2950-ST-24-LRE-997",
            "Cisco Systems | Catalyst 2950-ST-8-LRE",
            "Cisco Systems | Catalyst 2950C-24",
            "Cisco Systems | Catalyst 2950G-12",
            "Cisco Systems | Catalyst 2950G-24",
            "Cisco Systems | Catalyst 2950G-24-DC",
            "Cisco Systems | Catalyst 2950G-48",
            "Cisco Systems | Catalyst 2950SX-24",
            "Cisco Systems | Catalyst 2950T-24",
            "Cisco Systems | Catalyst 2955-S-12",
            "Cisco Systems | Catalyst 2955C-12",
            "Cisco Systems | Catalyst 2955T-12",
            "Cisco Systems | Catalyst 2960-24",
            "Cisco Systems | Catalyst 2960-24-S",
            "Cisco Systems | Catalyst 2960-24-TCS",
            "Cisco Systems | Catalyst 2960-24-TT",
            "Cisco Systems | Catalyst 2960-24LC-S",
            "Cisco Systems | Catalyst 2960-24LT",
            "Cisco Systems | Catalyst 2960-24PC",
            "Cisco Systems | Catalyst 2960-24PC-S",
            "Cisco Systems | Catalyst 2960-48",
            "Cisco Systems | Catalyst 2960-48-PS-TL",
            "Cisco Systems | Catalyst 2960-48-TCS",
            "Cisco Systems | Catalyst 2960-48-TT",
            "Cisco Systems | Catalyst 2960-48-TTS",
            "Cisco Systems | Catalyst 2960-48PST-S",
            "Cisco Systems | Catalyst 2960-8-TCS",
            "Cisco Systems | Catalyst 2960-8TC",
            "Cisco Systems | Catalyst 2960C-12PC-L",
            "Cisco Systems | Catalyst 2960C-8PC-L",
            "Cisco Systems | Catalyst 2960C-8TC-L",
            "Cisco Systems | Catalyst 2960C-8TC-S",
            "Cisco Systems | Catalyst 2960C-PD-8PT",
            "Cisco Systems | Catalyst 2960C-PD-8TT",
            "Cisco Systems | Catalyst 2960CG-8TC",
            "Cisco Systems | Catalyst 2960CX-8PC-L",
            "Cisco Systems | Catalyst 2960CX-8TC-L",
            "Cisco Systems | Catalyst 2960G-24",
            "Cisco Systems | Catalyst 2960G-48",
            "Cisco Systems | Catalyst 2960G-8TC",
            "Cisco Systems | Catalyst 2960P-24Lc-L",
            "Cisco Systems | Catalyst 2960P-24Lc-S",
            "Cisco Systems | Catalyst 2960P-24Pc-L",
            "Cisco Systems | Catalyst 2960P-24Pc-S",
            "Cisco Systems | Catalyst 2960P-24Tc-L",
            "Cisco Systems | Catalyst 2960P-24Tc-S",
            "Cisco Systems | Catalyst 2960P-48Pst-L",
            "Cisco Systems | Catalyst 2960P-48Pst-S",
            "Cisco Systems | Catalyst 2960P-48Tc-L",
            "Cisco Systems | Catalyst 2960P-48Tc-S",
            "Cisco Systems | Catalyst 2960PD-8TT",
            "Cisco Systems | Catalyst 2960S-24PD-L",
            "Cisco Systems | Catalyst 2960S-24TS-L",
            "Cisco Systems | Catalyst 2960S-24TS-S",
            "Cisco Systems | Catalyst 2960S-48FPD-L",
            "Cisco Systems | Catalyst 2960S-48FPS-L",
            "Cisco Systems | Catalyst 2960S-48LPD-L",
            "Cisco Systems | Catalyst 2960S-48LPS-L",
            "Cisco Systems | Catalyst 2960S-48TD-L",
            "Cisco Systems | Catalyst 2960S-48TS-S",
            "Cisco Systems | Catalyst 2960X 24PDL",
            "Cisco Systems | Catalyst 2960X 24PSL",
            "Cisco Systems | Catalyst 2960X 24PSQL",
            "Cisco Systems | Catalyst 2960X 24PSS",
            "Cisco Systems | Catalyst 2960X 24TDL",
            "Cisco Systems | Catalyst 2960X 24TSL",
            "Cisco Systems | Catalyst 2960X 24TSLL",
            "Cisco Systems | Catalyst 2960X 24TSS",
            "Cisco Systems | Catalyst 2960X 48FPDL",
            "Cisco Systems | Catalyst 2960X 48FPSL",
            "Cisco Systems | Catalyst 2960X 48LPDL",
            "Cisco Systems | Catalyst 2960X 48LPSL",
            "Cisco Systems | Catalyst 2960X 48LPSS",
            "Cisco Systems | Catalyst 2960X 48TDL",
            "Cisco Systems | Catalyst 2960X 48TSL",
            "Cisco Systems | Catalyst 2960X 48TSLL",
            "Cisco Systems | Catalyst 2960X 48TSS",
            "Cisco Systems | Catalyst 2960XR 24TDI",
            "Cisco Systems | Catalyst 2960XR 24TSI",
            "Cisco Systems | Catalyst 2960XR 48FPSI",
            "Cisco Systems | Catalyst 2960XR 48LPDI",
            "Cisco Systems | Catalyst 2960XR 48LPSI",
            "Cisco Systems | Catalyst 2960XR 48TDI",
            "Cisco Systems | Catalyst 2960XS 24PDL",
            "Cisco Systems | Catalyst 2960XS 24PSL",
            "Cisco Systems | Catalyst 2960XS 24TDL",
            "Cisco Systems | Catalyst 2960XS 24TSL",
            "Cisco Systems | Catalyst 2960XS 48FPDL",
            "Cisco Systems | Catalyst 2960XS 48FPSL",
            "Cisco Systems | Catalyst 2960XS 48LPDL",
            "Cisco Systems | Catalyst 2960XS 48LPSL",
            "Cisco Systems | Catalyst 2960XS 48LTDL",
            "Cisco Systems | Catalyst 2960XS 48TSL",
            "Cisco Systems | Catalyst 2970-24",
            "Cisco Systems | Catalyst 2970-24-TS",
            "Cisco Systems | Catalyst 2980G",
            "Cisco Systems | Catalyst 2980G-A",
            "Cisco Systems | Catalyst 29xx Stack",
            "Cisco Systems | Catalyst 3000",
            "Cisco Systems | Catalyst 3001",
            "Cisco Systems | Catalyst 3030",
            "Cisco Systems | Catalyst 3100",
            "Cisco Systems | Catalyst 3120G-S",
            "Cisco Systems | Catalyst 3120X",
            "Cisco Systems | Catalyst 3120X-S",
            "Cisco Systems | Catalyst 3125G",
            "Cisco Systems | Catalyst 3125X",
            "Cisco Systems | Catalyst 3130G-S",
            "Cisco Systems | Catalyst 3130X",
            "Cisco Systems | Catalyst 3130X-S",
            "Cisco Systems | Catalyst 3200",
            "Cisco Systems | Catalyst 3508G-XL",
            "Cisco Systems | Catalyst 3512XL",
            "Cisco Systems | Catalyst 3524-PWR-XL-EN",
            "Cisco Systems | Catalyst 3524XL",
            "Cisco Systems | Catalyst 3548XL",
            "Cisco Systems | Catalyst 3550-12G",
            "Cisco Systems | Catalyst 3550-12T",
            "Cisco Systems | Catalyst 3550-24",
            "Cisco Systems | Catalyst 3550-24-PWR",
            "Cisco Systems | Catalyst 3550-24DC",
            "Cisco Systems | Catalyst 3550-24MMF",
            "Cisco Systems | Catalyst 3550-48",
            "Cisco Systems | Catalyst 3560-12-PC-S",
            "Cisco Systems | Catalyst 3560-24PS",
            "Cisco Systems | Catalyst 3560-24TS",
            "Cisco Systems | Catalyst 3560-48PS",
            "Cisco Systems | Catalyst 3560-48TS",
            "Cisco Systems | Catalyst 3560-8PC",
            "Cisco Systems | Catalyst 3560C-12PC-S",
            "Cisco Systems | Catalyst 3560C-8PC-S",
            "Cisco Systems | Catalyst 3560CG-8PC-S",
            "Cisco Systems | Catalyst 3560CG-8TC-S",
            "Cisco Systems | Catalyst 3560CPD-8PT-S",
            "Cisco Systems | Catalyst 3560CX-12PC-S",
            "Cisco Systems | Catalyst 3560CX-12PD-S",
            "Cisco Systems | Catalyst 3560CX-12TC-S",
            "Cisco Systems | Catalyst 3560CX-8PC-S",
            "Cisco Systems | Catalyst 3560CX-8PT-S",
            "Cisco Systems | Catalyst 3560CX-8TC-S",
            "Cisco Systems | Catalyst 3560CX-8XPD-S",
            "Cisco Systems | Catalyst 3560E-12D-S",
            "Cisco Systems | Catalyst 3560E-12SD-E",
            "Cisco Systems | Catalyst 3560E-24PD-E",
            "Cisco Systems | Catalyst 3560E-24TD-E",
            "Cisco Systems | Catalyst 3560E-48PD-E",
            "Cisco Systems | Catalyst 3560E-48TD",
            "Cisco Systems | Catalyst 3560G-24PS",
            "Cisco Systems | Catalyst 3560G-24TS",
            "Cisco Systems | Catalyst 3560G-48PS",
            "Cisco Systems | Catalyst 3560G-48TS",
            "Cisco Systems | Catalyst 3560V2-24PS",
            "Cisco Systems | Catalyst 3560V2-24TS",
            "Cisco Systems | Catalyst 3560V2-24TS-SD",
            "Cisco Systems | Catalyst 3560V2-48PS",
            "Cisco Systems | Catalyst 3560X-24P",
            "Cisco Systems | Catalyst 3560X-24T",
            "Cisco Systems | Catalyst 3560X-24U",
            "Cisco Systems | Catalyst 3560X-48P",
            "Cisco Systems | Catalyst 3560X-48T",
            "Cisco Systems | Catalyst 3560X-48U",
            "Cisco Systems | Catalyst 3650-12X48UQ-L",
            "Cisco Systems | Catalyst 3650-12X48UR-L",
            "Cisco Systems | Catalyst 3650-12X48UZ-L",
            "Cisco Systems | Catalyst 3650-24PD",
            "Cisco Systems | Catalyst 3650-24PS",
            "Cisco Systems | Catalyst 3650-24TD",
            "Cisco Systems | Catalyst 3650-24TS",
            "Cisco Systems | Catalyst 3650-48PD",
            "Cisco Systems | Catalyst 3650-48PQ",
            "Cisco Systems | Catalyst 3650-48PS",
            "Cisco Systems | Catalyst 3650-48TD",
            "Cisco Systems | Catalyst 3650-48TQ",
            "Cisco Systems | Catalyst 3650-48TS",
            "Cisco Systems | Catalyst 3650-8X24UQ-L",
            "Cisco Systems | Catalyst 3650Stack",
            "Cisco Systems | Catalyst 36xx Stackable Ethernet",
            "Cisco Systems | Catalyst 3750-24",
            "Cisco Systems | Catalyst 3750-24-ME",
            "Cisco Systems | Catalyst 3750-24FS",
            "Cisco Systems | Catalyst 3750-24PS",
            "Cisco Systems | Catalyst 3750-24T",
            "Cisco Systems | Catalyst 3750-24TS",
            "Cisco Systems | Catalyst 3750-48",
            "Cisco Systems | Catalyst 3750-48PS",
            "Cisco Systems | Catalyst 3750E-24PD",
            "Cisco Systems | Catalyst 3750E-24TD",
            "Cisco Systems | Catalyst 3750E-48PD",
            "Cisco Systems | Catalyst 3750E-48TD",
            "Cisco Systems | Catalyst 3750G-16TD",
            "Cisco Systems | Catalyst 3750G-24PS",
            "Cisco Systems | Catalyst 3750G-24PS-E",
            "Cisco Systems | Catalyst 3750G-24TS-1U",
            "Cisco Systems | Catalyst 3750G-24WS-S25",
            "Cisco Systems | Catalyst 3750G-24WS-S50",
            "Cisco Systems | Catalyst 3750G-48PS-S",
            "Cisco Systems | Catalyst 3750G-48TS",
            "Cisco Systems | Catalyst 3750G-E-12-SFP-DC",
            "Cisco Systems | Catalyst 3750G-e-12-Sfp",
            "Cisco Systems | Catalyst 3750V2-24FS-S",
            "Cisco Systems | Catalyst 3750V2-24PS",
            "Cisco Systems | Catalyst 3750V2-24TS",
            "Cisco Systems | Catalyst 3750V2-48PS",
            "Cisco Systems | Catalyst 3750V2-48TS",
            "Cisco Systems | Catalyst 3750X-12-S",
            "Cisco Systems | Catalyst 3750X-24",
            "Cisco Systems | Catalyst 3750X-24-S",
            "Cisco Systems | Catalyst 3750X-24P",
            "Cisco Systems | Catalyst 3750X-48",
            "Cisco Systems | Catalyst 3750X-48P",
            "Cisco Systems | Catalyst 3750X-48U",
            "Cisco Systems | Catalyst 37xx Stackable Ethernet",
            "Cisco Systems | Catalyst 3850-12S",
            "Cisco Systems | Catalyst 3850-12X48U",
            "Cisco Systems | Catalyst 3850-24",
            "Cisco Systems | Catalyst 3850-24P",
            "Cisco Systems | Catalyst 3850-24S",
            "Cisco Systems | Catalyst 3850-24T",
            "Cisco Systems | Catalyst 3850-24U",
            "Cisco Systems | Catalyst 3850-24XS",
            "Cisco Systems | Catalyst 3850-48",
            "Cisco Systems | Catalyst 3850-48P",
            "Cisco Systems | Catalyst 3850-48U",
            "Cisco Systems | Catalyst 3850-48XS",
            "Cisco Systems | Catalyst 3900",
            "Cisco Systems | Catalyst 3920",
            "Cisco Systems | Catalyst 4000 NAM",
            "Cisco Systems | Catalyst 4000-Sup3",
            "Cisco Systems | Catalyst 4003",
            "Cisco Systems | Catalyst 4006",
            "Cisco Systems | Catalyst 4232-L3",
            "Cisco Systems | Catalyst 4500-X-16",
            "Cisco Systems | Catalyst 4500-X-32",
            "Cisco Systems | Catalyst 4500X",
            "Cisco Systems | Catalyst 4503",
            "Cisco Systems | Catalyst 4503E",
            "Cisco Systems | Catalyst 4506",
            "Cisco Systems | Catalyst 4506E",
            "Cisco Systems | Catalyst 4507R",
            "Cisco Systems | Catalyst 4507R-E",
            "Cisco Systems | Catalyst 4507RplusE",
            "Cisco Systems | Catalyst 4510",
            "Cisco Systems | Catalyst 4510R-E",
            "Cisco Systems | Catalyst 4510RplusE",
            "Cisco Systems | Catalyst 4840G-L3",
            "Cisco Systems | Catalyst 4900M",
            "Cisco Systems | Catalyst 4908G-L3",
            "Cisco Systems | Catalyst 4908G-L3-DC",
            "Cisco Systems | Catalyst 4912",
            "Cisco Systems | Catalyst 4928-10GE",
            "Cisco Systems | Catalyst 4948",
            "Cisco Systems | Catalyst 4948-10-GE",
            "Cisco Systems | Catalyst 4948E-10GE",
            "Cisco Systems | Catalyst 4948E-F",
            "Cisco Systems | Catalyst 5000",
            "Cisco Systems | Catalyst 5002",
            "Cisco Systems | Catalyst 5500",
            "Cisco Systems | Catalyst 5505",
            "Cisco Systems | Catalyst 5509",
            "Cisco Systems | Catalyst 6000",
            "Cisco Systems | Catalyst 6006",
            "Cisco Systems | Catalyst 6009",
            "Cisco Systems | Catalyst 6200",
            "Cisco Systems | Catalyst 6400NSP",
            "Cisco Systems | Catalyst 6500 SSL Services Module",
            "Cisco Systems | Catalyst 6503",
            "Cisco Systems | Catalyst 6504E",
            "Cisco Systems | Catalyst 6506",
            "Cisco Systems | Catalyst 6506/6506-E",
            "Cisco Systems | Catalyst 6509-CatOS",
            "Cisco Systems | Catalyst 6509-IOS",
            "Cisco Systems | Catalyst 6509-NEB-A",
            "Cisco Systems | Catalyst 6509-NEB-CatOS",
            "Cisco Systems | Catalyst 6509-NEB-IOS",
            "Cisco Systems | Catalyst 6509-NEBA",
            "Cisco Systems | Catalyst 6509-V-E",
            "Cisco Systems | Catalyst 6513-CatOS",
            "Cisco Systems | Catalyst 6513-IOS",
            "Cisco Systems | Catalyst 6800IA",
            "Cisco Systems | Catalyst 6807-XL",
            "Cisco Systems | Catalyst 6816-X",
            "Cisco Systems | Catalyst 6824-X",
            "Cisco Systems | Catalyst 6840-X",
            "Cisco Systems | Catalyst 6880-X",
            "Cisco Systems | Catalyst 6kMsfc2a",
            "Cisco Systems | Catalyst 8510-MSR",
            "Cisco Systems | Catalyst 8515-MSR",
            "Cisco Systems | Catalyst 8540",
            "Cisco Systems | Catalyst 8540-MSR",
            "Cisco Systems | Catalyst 9006",
            "Cisco Systems | Catalyst 9009",
            "Cisco Systems | Catalyst BS3020",
            "Cisco Systems | Catalyst CBS 3032-DEL",
            "Cisco Systems | Catalyst CBS 3040",
            "Cisco Systems | Catalyst E500-24LC",
            "Cisco Systems | Catalyst E500-24PC",
            "Cisco Systems | Catalyst E500-24TT",
            "Cisco Systems | Catalyst E500G-12TC",
            "Cisco Systems | Catalyst Express 520-24-LC",
            "Cisco Systems | Catalyst Express 520-24-PC",
            "Cisco Systems | Catalyst Express 520-24-TT",
            "Cisco Systems | Catalyst Express 520-8PC",
            "Cisco Systems | Catalyst Express 520G-24-TC",
            "Cisco Systems | Catalyst SUP32-8GE",
            "Cisco Systems | Catalyst SVC-FWM",
            "Cisco Systems | Catalyst SVC-FWM-1-K9",
            "Cisco Systems | Catalyst WS-C3650-48PQM",
            "Cisco Systems | Catalyst WS-C6503",
            "Cisco Systems | Catalyst WS-CBS3012-IBM",
            "Cisco Systems | Catalyst WS-CBS3012-IBM-I",
            "Cisco Systems | Catalyst WS-CBS3100",
            "Cisco Systems | Catalyst WS-CBS310G-S-T",
            "Cisco Systems | Catalyst WS-CBS3110",
            "Cisco Systems | Catalyst WS-CBS3110G-S",
            "Cisco Systems | Catalyst WS-CBS3110X-S",
            "Cisco Systems | Catalyst WS-CBS3110X-S-T",
            "Cisco Systems | Catalyst WS-F5541",
            "Cisco Systems | Catalyst WS-SCV-CMM",
            "Cisco Systems | Catalyst WS-SUP720",
            "Cisco Systems | Catalyst WS-X4604-GWY",
            "Cisco Systems | Catalyst WS-X5302",
            "Cisco Systems | Catalyst WS-X6302MSM",
            "Cisco Systems | Catalyst WSC 1900 LiteFX",
            "Cisco Systems | Catalyst WSC 6513 (Virtual)",
            "Cisco Systems | Cisco PWS 2200",
            "Cisco Systems | Contact Center Express",
            "Cisco Systems | Contact Center Express Cluster",
            "Cisco Systems | Contact Center Express Server",
            "Cisco Systems | Content Switching Module",
            "Cisco Systems | ContentEngine",
            "Cisco Systems | DPA 7630",
            "Cisco Systems | DS C9120 CL",
            "Cisco Systems | EPS 2015",
            "Cisco Systems | ESX-NAM",
            "Cisco Systems | Emergency Responder",
            "Cisco Systems | Esw52024pK9",
            "Cisco Systems | Esw52048K9",
            "Cisco Systems | Esw52048pK9",
            "Cisco Systems | Esw54048K9",
            "Cisco Systems | FE 2636",
            "Cisco Systems | FE 511-K9",
            "Cisco Systems | FE 512",
            "Cisco Systems | FE 6326",
            "Cisco Systems | FE 7326",
            "Cisco Systems | Firepower 4120 K9",
            "Cisco Systems | Firepower 4140 K9",
            "Cisco Systems | Firepower 4150 K9",
            "Cisco Systems | HCM-F Cluster",
            "Cisco Systems | HCM-F Server",
            "Cisco Systems | HCS Intelligent Loader Cluster",
            "Cisco Systems | HCS Intelligent Loader Server",
            "Cisco Systems | HWIC Cable EJ-2",
            "Cisco Systems | IAD2420",
            "Cisco Systems | IAD886F",
            "Cisco Systems | IAD887F",
            "Cisco Systems | IAD888F",
            "Cisco Systems | IDS 4215 Virtual Sensor",
            "Cisco Systems | IDS 4220 Sensor",
            "Cisco Systems | IDS 4235 Sensor",
            "Cisco Systems | IDS 4240 Sensor",
            "Cisco Systems | IDS 4250SX Sensor",
            "Cisco Systems | IDS 4250SX Virtual Sensor",
            "Cisco Systems | IDS 4250XL Sensor",
            "Cisco Systems | IDS 4250XL Virtual Sensor",
            "Cisco Systems | IDS 4255 Virtual Sensor",
            "Cisco Systems | IDS IDSM-2 Virtual Sensor",
            "Cisco Systems | IDSN MCIDS",
            "Cisco Systems | IE 1000 4TLM",
            "Cisco Systems | IE 1000 6TLM",
            "Cisco Systems | IE 2000 16TC",
            "Cisco Systems | IE 2000 16TC G",
            "Cisco Systems | IE 2000 16TC GE P",
            "Cisco Systems | IE 2000 16TC GN",
            "Cisco Systems | IE 2000 16TC GN XP",
            "Cisco Systems | IE 2000 16TC GP",
            "Cisco Systems | IE 2000 16TC GX",
            "Cisco Systems | IE 2000 4T",
            "Cisco Systems | IE 2000 4T G",
            "Cisco Systems | IE 2000 4TS",
            "Cisco Systems | IE 2000 4TS G",
            "Cisco Systems | IE 2000 8TC",
            "Cisco Systems | IE 2000 8TC G",
            "Cisco Systems | IE 2000-16T67-B",
            "Cisco Systems | IE 2000-16T67P-G-E",
            "Cisco Systems | IE 2000-24T67-B",
            "Cisco Systems | IE 2000-8T67-B",
            "Cisco Systems | IE 2000-8T67P-G-E",
            "Cisco Systems | IE 2000-8TC-G-N",
            "Cisco Systems | IE 2000U 16TC G",
            "Cisco Systems | IE 2000U 4ST SG",
            "Cisco Systems | IE 2000U 4T G",
            "Cisco Systems | IE 2000U-16TC-GP",
            "Cisco Systems | IE 2105",
            "Cisco Systems | IE 3000-4TC",
            "Cisco Systems | IE 3000-8TC",
            "Cisco Systems | IE 3010-16S-8PC",
            "Cisco Systems | IE 3010-24-TC",
            "Cisco Systems | IE 4000 16GT 4GE",
            "Cisco Systems | IE 4000 4GC 4GP 4GE",
            "Cisco Systems | IE 4000 4S 8P 4GE",
            "Cisco Systems | IE 4000 4TC 4GE",
            "Cisco Systems | IE 4000 8GT 4GE",
            "Cisco Systems | IE 4000 8S 4GE",
            "Cisco Systems | IE 4000 8T 4GE",
            "Cisco Systems | IE 4010 16S 12P",
            "Cisco Systems | IE 4010 4S 24P",
            "Cisco Systems | IE 5000 12S 12P 10G",
            "Cisco Systems | IE 5000 16S 12P",
            "Cisco Systems | IGESM-SFP",
            "Cisco Systems | IGESM-SFP-T",
            "Cisco Systems | IGESM-T",
            "Cisco Systems | IGX 8410",
            "Cisco Systems | IGX 8420",
            "Cisco Systems | IGX 8430",
            "Cisco Systems | IGX 8450",
            "Cisco Systems | IGX SES",
            "Cisco Systems | IM and Presence Cluster",
            "Cisco Systems | IM and Presence Server",
            "Cisco Systems | IPCC",
            "Cisco Systems | IPS 4270 Virtual Sensor",
            "Cisco Systems | IPS SSC-5 Virtual",
            "Cisco Systems | IPS SSC2",
            "Cisco Systems | IPS SSC2 Virtual",
            "Cisco Systems | IPS SSM-20 Virtual Sensor",
            "Cisco Systems | IPS SSM-40",
            "Cisco Systems | IPS SSM-40 Virtual",
            "Cisco Systems | IPS Virtual Sensor",
            "Cisco Systems | IR 809G-LTE-GA-K9",
            "Cisco Systems | IR 809G-LTE-NA-K9",
            "Cisco Systems | IR 809G-LTE-ST-K9",
            "Cisco Systems | IR 829GW-LTE-GA-EK9",
            "Cisco Systems | IR 829GW-LTE-GA-ZK9",
            "Cisco Systems | IR 829GW-LTE-ST-AK9",
            "Cisco Systems | ISR Wireless",
            "Cisco Systems | LS 1015",
            "Cisco Systems | Lightstream 1010",
            "Cisco Systems | Lightstream 1010 Chassis",
            "Cisco Systems | Lightstream 1015",
            "Cisco Systems | MCS 7816H",
            "Cisco Systems | MCS 7816I",
            "Cisco Systems | MCS 7828I",
            "Cisco Systems | MCS 7845H",
            "Cisco Systems | MDE-1125-K9",
            "Cisco Systems | MDE-50IVB-K9",
            "Cisco Systems | MDS 9116-K9",
            "Cisco Systems | MDS 9120",
            "Cisco Systems | MDS 9124",
            "Cisco Systems | MDS 9124e",
            "Cisco Systems | MDS 9132-K9",
            "Cisco Systems | MDS 9134",
            "Cisco Systems | MDS 9140",
            "Cisco Systems | MDS 9148-K9",
            "Cisco Systems | MDS 9148S-K9",
            "Cisco Systems | MDS 9216",
            "Cisco Systems | MDS 9216-K9",
            "Cisco Systems | MDS 9216A",
            "Cisco Systems | MDS 9216I-K9",
            "Cisco Systems | MDS 9222I-K9",
            "Cisco Systems | MDS 9250I-K9",
            "Cisco Systems | MDS 9250i IFS",
            "Cisco Systems | MDS 9250i IFSDC",
            "Cisco Systems | MDS 9250i-IFS",
            "Cisco Systems | MDS 9250i-IFS-DC",
            "Cisco Systems | MDS 9396",
            "Cisco Systems | MDS 9506",
            "Cisco Systems | MDS 9509",
            "Cisco Systems | MDS 9513",
            "Cisco Systems | MDS 9706",
            "Cisco Systems | MDS 9710",
            "Cisco Systems | MDS 9718",
            "Cisco Systems | MDS IBM-FC-K9",
            "Cisco Systems | ME 2400-24TS-A",
            "Cisco Systems | ME 2400-24TS-D",
            "Cisco Systems | ME 2600X",
            "Cisco Systems | ME 3400-24FS-A",
            "Cisco Systems | ME 3400-24TS-A",
            "Cisco Systems | ME 3400-24TS-D",
            "Cisco Systems | ME 3600X-24FS-M",
            "Cisco Systems | ME 3600X-24TS-M",
            "Cisco Systems | ME 3800X-24FS-M",
            "Cisco Systems | ME 4924-10GE",
            "Cisco Systems | ME 6524GS-8S",
            "Cisco Systems | ME 6524GT-8S",
            "Cisco Systems | ME-3400E-24TS-M",
            "Cisco Systems | ME-3400EG-12CS-M",
            "Cisco Systems | ME-3400EG-2CS-A",
            "Cisco Systems | ME-3400G-12CS-A",
            "Cisco Systems | ME-3400G-12CS-D",
            "Cisco Systems | ME-3400G-2CS-A",
            "Cisco Systems | ME-6340-AC-A",
            "Cisco Systems | ME-6340-DC-A",
            "Cisco Systems | ME-6340-DC-B",
            "Cisco Systems | MGX 8230",
            "Cisco Systems | MGX 8240",
            "Cisco Systems | MGX 8250",
            "Cisco Systems | MGX 8830",
            "Cisco Systems | MGX 8830 PXM1E",
            "Cisco Systems | MGX 8830 PXM45",
            "Cisco Systems | MGX 8850",
            "Cisco Systems | MGX 8850 PXM1E",
            "Cisco Systems | MGX 8850 PXM45",
            "Cisco Systems | MGX 8850-PXM-1E",
            "Cisco Systems | MGX 8860",
            "Cisco Systems | MGX 8880",
            "Cisco Systems | MGX 8950",
            "Cisco Systems | MPX",
            "Cisco Systems | MWAM",
            "Cisco Systems | N5K C5020-P-BD",
            "Cisco Systems | N5K-C5020-P-BA",
            "Cisco Systems | NAM-2420",
            "Cisco Systems | NAM-2440",
            "Cisco Systems | NAM2204",
            "Cisco Systems | NAM2220",
            "Cisco Systems | NCS 6008",
            "Cisco Systems | NGA 3140-K9",
            "Cisco Systems | NGA 3340-K9",
            "Cisco Systems | NM AON APS",
            "Cisco Systems | NM AON WS",
            "Cisco Systems | NM CUE",
            "Cisco Systems | NM CUE EC",
            "Cisco Systems | NME APA",
            "Cisco Systems | NME CUE",
            "Cisco Systems | NME WAE-302-K9",
            "Cisco Systems | NME WAE-502-K9",
            "Cisco Systems | NME WAE-522-K9",
            "Cisco Systems | NME-16ES-1G",
            "Cisco Systems | NME-16ES-1G-P",
            "Cisco Systems | NME-48ES-1G-P",
            "Cisco Systems | NME-NAM",
            "Cisco Systems | NME-X-23ES-1G",
            "Cisco Systems | NME-XD-24ES-2S-P",
            "Cisco Systems | NME-XD-48ES-2G-P",
            "Cisco Systems | NME-XD-48ES-2S-P",
            "Cisco Systems | NX-NAM-1",
            "Cisco Systems | Network Registrar",
            "Cisco Systems | Nexus 1000-VH",
            "Cisco Systems | Nexus 1000v",
            "Cisco Systems | Nexus 1010X",
            "Cisco Systems | Nexus 1110S",
            "Cisco Systems | Nexus 1110XL",
            "Cisco Systems | Nexus 2148T-1GE",
            "Cisco Systems | Nexus 2224",
            "Cisco Systems | Nexus 2232PP-10GE",
            "Cisco Systems | Nexus 2232TM-10GE",
            "Cisco Systems | Nexus 2248",
            "Cisco Systems | Nexus 2248TP-1GE",
            "Cisco Systems | Nexus 3016Q-40GE",
            "Cisco Systems | Nexus 3048TP-1GE",
            "Cisco Systems | Nexus 3064PQ",
            "Cisco Systems | Nexus 3064PQ10GE",
            "Cisco Systems | Nexus 3064TQ10GT",
            "Cisco Systems | Nexus 3548P-10G",
            "Cisco Systems | Nexus 4001I-XPX",
            "Cisco Systems | Nexus 4005I-XPX",
            "Cisco Systems | Nexus 5010P-BF",
            "Cisco Systems | Nexus 5020P-BA",
            "Cisco Systems | Nexus 5020P-BD",
            "Cisco Systems | Nexus 5020T-BF",
            "Cisco Systems | Nexus 5548P",
            "Cisco Systems | Nexus 5548UP",
            "Cisco Systems | Nexus 5596T-FA",
            "Cisco Systems | Nexus 5596UP-FA",
            "Cisco Systems | Nexus 56128P",
            "Cisco Systems | Nexus 5648Q",
            "Cisco Systems | Nexus 5672UP",
            "Cisco Systems | Nexus 5696Q",
            "Cisco Systems | Nexus 6001-64P",
            "Cisco Systems | Nexus 6001-64T",
            "Cisco Systems | Nexus 6004-96Q",
            "Cisco Systems | Nexus 7004",
            "Cisco Systems | Nexus 7009",
            "Cisco Systems | Nexus 7010",
            "Cisco Systems | Nexus 7018",
            "Cisco Systems | Nexus 7702",
            "Cisco Systems | Nexus 7706",
            "Cisco Systems | Nexus 7710",
            "Cisco Systems | Nexus 7718",
            "Cisco Systems | Nexus 93120TX",
            "Cisco Systems | Nexus 9332PQ",
            "Cisco Systems | Nexus 9372PX",
            "Cisco Systems | Nexus 9372TX",
            "Cisco Systems | Nexus 9396PX",
            "Cisco Systems | Nexus 9504",
            "Cisco Systems | Nexus 9508",
            "Cisco Systems | Nexus B22HP-P",
            "Cisco Systems | Nexus N9K-C93180LC-EX",
            "Cisco Systems | Nexus N9K-C93180YC-EX",
            "Cisco Systems | OEM",
            "Cisco Systems | ONS 15310",
            "Cisco Systems | ONS 15327",
            "Cisco Systems | ONS 15454",
            "Cisco Systems | ONS 15530",
            "Cisco Systems | ONS 15530 NEBS",
            "Cisco Systems | ONS 15530-ETSI",
            "Cisco Systems | ONS 15540-ESP",
            "Cisco Systems | ONS 15540-ESPx",
            "Cisco Systems | ONS-15501-AX",
            "Cisco Systems | ONS-15501-DC",
            "Cisco Systems | ONS-RAN-SVC",
            "Cisco Systems | PIX 515E SY",
            "Cisco Systems | PIX 525 SY",
            "Cisco Systems | Prime Collaboration Deployment Cluster",
            "Cisco Systems | Prime Collaboration Deployment Server",
            "Cisco Systems | Prime License Manager Cluster",
            "Cisco Systems | Prime License Manager Server",
            "Cisco Systems | Probe6020",
            "Cisco Systems | Probe6060",
            "Cisco Systems | Probe7103",
            "Cisco Systems | Probe7213",
            "Cisco Systems | Probe7302",
            "Cisco Systems | Probe7500",
            "Cisco Systems | Probe8722",
            "Cisco Systems | SAMI-BB",
            "Cisco Systems | SCE 1000",
            "Cisco Systems | SCE 10000",
            "Cisco Systems | SCE 2000",
            "Cisco Systems | SCE 8000",
            "Cisco Systems | SM SRE-700-K9",
            "Cisco Systems | SM SRE-900-K9",
            "Cisco Systems | SM-D-ES2-48",
            "Cisco Systems | SM-D-ES3-48-P",
            "Cisco Systems | SM-D-ES3G-48-P",
            "Cisco Systems | SM-ES2-16-P",
            "Cisco Systems | SM-ES2-24",
            "Cisco Systems | SM-ES2-24-P",
            "Cisco Systems | SM-ES3-16-P",
            "Cisco Systems | SM-ES3-24-P",
            "Cisco Systems | SM-ES3G-16-P",
            "Cisco Systems | SM-ES3G-24-P",
            "Cisco Systems | SNS 3945-K9",
            "Cisco Systems | SSL Content Switch Module",
            "Cisco Systems | Secure Access Control System",
            "Cisco Systems | SocialMiner Cluster",
            "Cisco Systems | SocialMiner Server",
            "Cisco Systems | Standby GSSM",
            "Cisco Systems | TS SEC",
            "Cisco Systems | Tandberg 1500 MXP",
            "Cisco Systems | Tandberg 2000 MXP",
            "Cisco Systems | Tandberg 550 MXP",
            "Cisco Systems | Tandberg 7000 MXP Dual",
            "Cisco Systems | Tandberg 770 MXP",
            "Cisco Systems | Tandberg 8000 MXP",
            "Cisco Systems | Tandberg 880 MXP",
            "Cisco Systems | Tandberg 990 MXP",
            "Cisco Systems | Tandberg Codec",
            "Cisco Systems | TelePresence Conductor Cluster",
            "Cisco Systems | TelePresence System 1000 MXP",
            "Cisco Systems | TelePresence System 1700 MXP",
            "Cisco Systems | TelePresence System Codec 3000 MXP",
            "Cisco Systems | TelePresence System Codec 6000 MXP",
            "Cisco Systems | TelePresence System Edge 75 MXP",
            "Cisco Systems | TelePresence System Edge 85 MXP",
            "Cisco Systems | TelePresence System Edge 95 MXP",
            "Cisco Systems | TelePresence System MXP",
            "Cisco Systems | UC 520M-24U-4BRI",
            "Cisco Systems | UC 520M-24U-8FXO",
            "Cisco Systems | UC 520M-32U-4BRI",
            "Cisco Systems | UC 520M-32U-4BRIW",
            "Cisco Systems | UC 520M-32U-8FXO",
            "Cisco Systems | UC 520M-32U-8FXOW",
            "Cisco Systems | UC 520M-48U-12FXO",
            "Cisco Systems | UC 520M-48U-12FXOW",
            "Cisco Systems | UC 520M-48U-1T-1E-1B",
            "Cisco Systems | UC 520M-48U-1T-1E-1F",
            "Cisco Systems | UC 520M-48U-6BRI",
            "Cisco Systems | UC 520M-48U-6BRIW",
            "Cisco Systems | UC 520S-16U-2BRI",
            "Cisco Systems | UC 520S-16U-2BRIW",
            "Cisco Systems | UC 520S-16U-2BRIW-J",
            "Cisco Systems | UC 520S-16U-4FXO",
            "Cisco Systems | UC 520S-16U-4FXOW",
            "Cisco Systems | UC 520S-8U-2BRI",
            "Cisco Systems | UC 520S-8U-2BRIW",
            "Cisco Systems | UC 520S-8U-2BRIW-J",
            "Cisco Systems | UC 520S-8U-4FXO",
            "Cisco Systems | UC 520S-8U-4FXOW",
            "Cisco Systems | UC Virtual Machine",
            "Cisco Systems | UCS C210 Rack Server",
            "Cisco Systems | UCS C220 M5",
            "Cisco Systems | UCS C240  Rack Server",
            "Cisco Systems | UCS C240 M4 Rack Server",
            "Cisco Systems | UCS C250  Rack Server",
            "Cisco Systems | UCS C3160 Rack Server",
            "Cisco Systems | UCS C460 M4 Rack Server",
            "Cisco Systems | UCS E120S-M2",
            "Cisco Systems | UCS E140D",
            "Cisco Systems | UCS E140D Rack Server",
            "Cisco Systems | UCS E140DP",
            "Cisco Systems | UCS E140DP Rack Server",
            "Cisco Systems | UCS E140S",
            "Cisco Systems | UCS E140S Rack Server",
            "Cisco Systems | UCS E160DP",
            "Cisco Systems | UCS E160DP Rack Server",
            "Cisco Systems | UCS EN 120S",
            "Cisco Systems | UCS-E160D-M2",
            "Cisco Systems | UCS-E180D-M2",
            "Cisco Systems | UCS-EN120E-108",
            "Cisco Systems | UCS-EN120E-54",
            "Cisco Systems | UCS-EN120S-M2",
            "Cisco Systems | Unity Connection Cluster",
            "Cisco Systems | Unity Connection Server",
            "Cisco Systems | VFrame Data Center",
            "Cisco Systems | VG 202XM",
            "Cisco Systems | VG 204XM",
            "Cisco Systems | VG 226E",
            "Cisco Systems | VG 250",
            "Cisco Systems | VG 310",
            "Cisco Systems | VG 320",
            "Cisco Systems | VG 350",
            "Cisco Systems | VG-248",
            "Cisco Systems | VG202",
            "Cisco Systems | VG204",
            "Cisco Systems | VPS1110",
            "Cisco Systems | VQE IST",
            "Cisco Systems | VQE Server",
            "Cisco Systems | VQE Tools",
            "Cisco Systems | VS Encoder-1P",
            "Cisco Systems | VS Encoder-4P",
            "Cisco Systems | VS INT SP",
            "Cisco Systems | VSSP",
            "Cisco Systems | Virtual WAAS",
            "Cisco Systems | Virtual Wireless Controller",
            "Cisco Systems | WAAS NAM Blade",
            "Cisco Systems | WAE 511-K9",
            "Cisco Systems | WAE 512",
            "Cisco Systems | WAE 611-K9",
            "Cisco Systems | WAE 612",
            "Cisco Systems | WAE 612-K9",
            "Cisco Systems | WAE 674-K9",
            "Cisco Systems | WAE 7341-K9",
            "Cisco Systems | WAE-611",
            "Cisco Systems | WAVE 574-K9",
            "Cisco Systems | WAVE 694-K9",
            "Cisco Systems | WAVE 7541-K9",
            "Cisco Systems | WAVE 8541-K9",
            "Cisco Systems | WISM2",
            "Cisco Systems | WLSE",
            "Cisco Systems | WLSE 1030",
            "Cisco Systems | WLSE 1130",
            "Cisco Systems | WLSE 1133",
            "Cisco Systems | WS-C2960S-24PS-L",
            "Cisco Systems | WS-C2960S-48TS-L",
            "Cisco Systems | WS-C2975GS-48PS-L",
            "Cisco Systems | WS-C2975GS-48PS-L Stack",
            "Cisco Systems | WS-C3560V2-48TS",
            "Cisco Systems | WS-SVC-NAM-2",
            "Cisco Systems | WS-SVX-NAM-3",
            "Cisco Systems | esStack",
            "Cisco Systems | tsStack",
            "Cisco TelePresence | CTS-(unknown model)",
            "Cisco TelePresence | CTS-1000",
            "Cisco TelePresence | CTS-1100",
            "Cisco TelePresence | CTS-1300",
            "Cisco TelePresence | CTS-3000",
            "Cisco TelePresence | CTS-3010",
            "Cisco TelePresence | CTS-3200",
            "Cisco TelePresence | CTS-3210",
            "Cisco TelePresence | CTS-500",
            "Cisco TelePresence | CTS-500-32",
            "Cisco TelePresence | CTS-TX1310",
            "Cisco TelePresence | CTS-TX9000",
            "Cisco TelePresence | CTS-TX9200",
            "Cisco TelePresence | Cisco TelePresence Manager",
            "Cisco TelePresence | Exchange System (CTX)",
            "Cisco TelePresence | IX5000",
            "Cisco TelePresence | IX5200",
            "Cisco TelePresence | Media Experience Engine (MXE) 5600",
            "Cisco TelePresence | Multipoint Switch (CTMS)",
            "Cisco TelePresence | Recording Server (CTRS)",
            "Cisco TelePresence | Unified Videoconferencing Manager (CUVM)",
            "Corecess Inc. | OEM",
            "D-Link | DES-3224 Ethernet Switching Hub",
            "D-Link | DES-3225G Standalone Switch",
            "D-Link | DES-3226 Fast Ethernet Switch",
            "D-Link | DES-3226S Fast-Ether Switch",
            "D-Link | DGS 3308 TG",
            "DASAN Co.,LTD. | OEM",
            "DASAN Co.,LTD. | V5116F CO Switch",
            "DEC | 900EF, 6-Ethernet/FDDI Switch",
            "DEC | GIGAswitch Network Platform",
            "Dell | OEM",
            "Dell | PowerConnect 3024",
            "Dell | PowerConnect 3324",
            "Dell | PowerConnect 3348",
            "Dell | PowerConnect 3424",
            "Dell | PowerConnect 3424P",
            "Dell | PowerConnect 3448",
            "Dell | PowerConnect 3448P",
            "Dell | PowerConnect 3524P",
            "Dell | PowerConnect 5212",
            "Dell | PowerConnect 5224",
            "Dell | PowerConnect 5324",
            "Dell | PowerConnect 6024",
            "Dell | PowerConnect 6224",
            "Dell | PowerConnect 6224P",
            "Dell | PowerConnect 6248",
            "Dell | PowerConnect 6248P",
            "Dell | PowerConnect M6220",
            "Digital Products, Inc. | OEM",
            "Eastern Research Inc. | OEM",
            "Eastern Research Inc. | Research, Inc. DNX 11 -",
            "Eastern Research Inc. | Software Rev 10.9c, Hardware",
            "Emerson Computer Power | OEM",
            "Enterasys Networks | 16 port 100BaseFX switch (Cablet",
            "Enterasys Networks | 2E42-27R",
            "Enterasys Networks | 2H252-25R",
            "Enterasys Networks | 6E122-26",
            "Enterasys Networks | 6E233-49",
            "Enterasys Networks | 6H202-24",
            "Enterasys Networks | 6H252-17",
            "Enterasys Networks | 9A128-01",
            "Enterasys Networks | 9E138-36",
            "Enterasys Networks | 9E428-36",
            "Enterasys Networks | 9F426-02",
            "Enterasys Networks | ELM Rev 2.06.03 3_PACK",
            "Enterasys Networks | ELS100-24TXM",
            "Enterasys Networks | EMME Management Board",
            "Enterasys Networks | Horizon Stack",
            "Enterasys Networks | Horizon VH-2402S",
            "Enterasys Networks | Horizon VH-8TX1UM/1MF",
            "Enterasys Networks | Networks 6E308-48",
            "Enterasys Networks | SSR 2000",
            "Enterasys Networks | Smart Switch 6000 Chassis (Enter",
            "Enterasys Networks | TRMM Revision 3.01.01",
            "Enterasys Networks | TRMM-2",
            "Enterasys Networks | TRMM-4",
            "Enterasys Networks | Vertical Horizon VH-2402s",
            "Enterasys Networks | Vertical Horizon VH-8G",
            "Enterasys Networks | X-Pedition 8600",
            "Enterasys Networks | X-pedition ER-16",
            "Extreme Networks | BD6808  Version 7.1.1",
            "Extreme Networks | Extreme X450A-48T",
            "Extreme Networks | MSM64  Version 6.2.2",
            "Extreme Networks | Networks 5i",
            "Extreme Networks | Networks Summit 24",
            "Extreme Networks | Networks Summit 48",
            "Extreme Networks | Networks Summit 48 iA1",
            "Extreme Networks | OEM",
            "Extreme Networks | Summit48si  Version 7.1.1",
            "Extreme Networks | networks Alpine 3808 switch",
            "F5 Networks, Inc. | BIG-IP 7255",
            "F5 Networks, Inc. | BIG-IP ARX1000",
            "F5 Networks, Inc. | BIG-IP ARX4000",
            "F5 Networks, Inc. | BIG-IP FirePass 4300",
            "F5 Networks, Inc. | BIG-IP TrafficShield 4100",
            "F5 Networks, Inc. | BIG-IP WJ400",
            "Fore Systems | 9A000",
            "Fore Systems | OEM",
            "Fore Systems | Systems, ES-2810 FORE ES-2810",
            "Forte Networks Inc. | Networks 1-touch",
            "Forte Networks Inc. | Networks OptiView Integrated Net",
            "Foundry Networks | FastIron Workgroup Switch",
            "Foundry Networks | Foundry Networks, Inc. FI4802,",
            "Foundry Networks | Router",
            "Foundry Networks | ServerIron Switch (SW 7.1.02T12)",
            "Foundry Networks | ServerIron Switch (SW 7.1.21T12)",
            "Foundry Networks | ServerIron Switch (SW V6)",
            "HP | 28673A Bridge",
            "HP | 28674A Bridge",
            "HP | 9304 Routing Switch",
            "HP | A5820",
            "HP | HP-UX 700 Agent",
            "HP | HP-UX 800 Agent",
            "HP | J2418A Hub",
            "HP | J3299A ProCurve Switch 224M",
            "HP | J4093A ProCurve Switch 2424M",
            "HP | J4110A ProCurve Switch 8000M",
            "HP | J4120A ProCurve Switch 1600M",
            "HP | J4121A ProCurve Switch 4000M",
            "HP | J4122A ProCurve Switch 2400M",
            "HP | J4138A ProCurve Switch 9300",
            "HP | J4812A ProCurve Switch 2512",
            "HP | J4813A ProCurve Switch 2524",
            "HP | J4850A ProCurve Switch 5304XL",
            "HP | J4865A ProCurve Switch 4108GL",
            "HP | LanProbe II - HP4995A",
            "HP | ProCurve Switch",
            "HP | ProCurve Switch 4104GL",
            "HP | Procurve Switch 2650",
            "HP | S5800-32C-PWR",
            "HP | StorageWorks P2000 G3 iSCSI",
            "HP | Switch 16",
            "HP | Switch 200",
            "HP | Switch 2000",
            "HP | TR LanProbe - HP4985A",
            "HUAWEI Technology CoLtd | HUA WEI CORP. SNMP",
            "HanA Systems, Inc. | Rustle 324M Switch",
            "Hitachi Ltd | OEM",
            "IBM | 8275-322 Fast Ethernet Switch",
            "IBM | Switch c2600",
            "Infinite Networks, Ltd. | OEM",
            "Intel Corporation | 510T Express 510T Switch",
            "Intel Corporation | 520T Express 520T Switch",
            "Intel Corporation | Express 460T-16 Standalone Switch (",
            "Intel Corporation | Express 460T-24 Standalone Switch (",
            "Intel Corporation | Express 530T Switch",
            "Intel Corporation | Express 550T Switch",
            "Intel Corporation | Express Gigabit Switch",
            "Intel Corporation | NetStructure(TM) 470F Switch",
            "Intel Corporation | NetStructure(TM) 480T Routing Sw",
            "Juniper Networks | EX2200 Switch",
            "Juniper Networks | EX3200 Switch",
            "Juniper Networks | EX3300 Switch",
            "Juniper Networks | EX4200 Switch",
            "Juniper Networks | EX4300 Switch",
            "Juniper Networks | EX4500 Switch",
            "Juniper Networks | EX4600 Switch",
            "Juniper Networks | EX8208 Chassis Switch",
            "Juniper Networks | EX8216 Chassis Switch",
            "Juniper Networks | OEM",
            "Juniper Networks | SRX210 Firewall",
            "Juniper Networks | SRX650 Firewall",
            "Konica Corporation | OEM",
            "Lantronix | EPS1",
            "Livingston Enterprises | OEM",
            "Lucent Technologies | OEM",
            "Lucent Technologies | Technologies Cajun Switch Agent",
            "Madge Networks | OEM",
            "Madge Networks | Smart Ringswitch Hardware",
            "Marconi | OEM",
            "McData Corporation | Edge-24 Model 001 Fibre Channel",
            "McData Corporation | OEM",
            "Mitel, Corp. | Networks 3300 VOIP ICP",
            "NBASE Switch Communication | Express Ethernet Switch (multipl",
            "NBASE Switch Communication | OEM",
            "NetApp | NetCache",
            "NetBotz | Linux NETBOTZ 2.4.26 #1",
            "NetScout Systems | Probe5010",
            "NetScout Systems | Probe6020",
            "NetScout Systems | Probe6060",
            "NetScout Systems | Probe7103",
            "NetScout Systems | Probe7213",
            "NetScout Systems | Probe7302",
            "NetScout Systems | Probe7500",
            "NetScout Systems | Probe8722",
            "NetStar | OEM",
            "Netopia | Netopia R5300",
            "Network Appliance | OEM",
            "Network Equipment Technologies | OEM",
            "Nortel | BayStack Instant Internet",
            "Northern Telecom Ltd | OEM",
            "Novell | OEM",
            "NxNetworks | Portable M68360 C Gateway",
            "Optical Transmission Labs | OEM",
            "Performance Technology, Inc. | OEM",
            "PlainTree Systems | OEM",
            "Plaintree bridge | WaveSwitch 100",
            "Polycom | Video Conferencing Device",
            "Radware | LinkProof-Branch",
            "Rapid City Communications | Passport-1624G",
            "Redback Networks | OEM",
            "Riverstone Networks | RS 3000 - Riverstone",
            "Rockwell Automation | Stratix 5400 IE1783-HMS16T4CGN",
            "Rockwell Automation | Stratix 5400 IE1783-HMS16TG4CGN",
            "Rockwell Automation | Stratix 5400 IE1783-HMS4C4CGN",
            "Rockwell Automation | Stratix 5400 IE1783-HMS4EG8CGN",
            "Rockwell Automation | Stratix 5400 IE1783-HMS4S8E4CGN",
            "Rockwell Automation | Stratix 5400 IE1783-HMS4SG8EG4CGN",
            "Rockwell Automation | Stratix 5400 IE1783-HMS4SG8EG4CGR",
            "Rockwell Automation | Stratix 5400 IE1783-HMS8SG4CGN",
            "Rockwell Automation | Stratix 5400 IE1783-HMS8SG4CGR",
            "Rockwell Automation | Stratix 5400 IE1783-HMS8T4CGN",
            "Rockwell Automation | Stratix 5400 IE1783-HMS8TG4CGR",
            "Rockwell Automation | Stratix 5400 IE1783-HMS8TG8EG4CGR",
            "Rockwell Automation | Stratix 5410 IE1783-IMS28GNDC",
            "Rockwell Automation | Stratix 5410 IE1783-IMS28GRAC",
            "Rockwell Automation | Stratix 5410 IE1783-IMS28NAC",
            "Rockwell Automation | Stratix 5410 IE1783-IMS28RAC",
            "Rockwell Automation | Stratix 5410 IE1783-IMS28RDC",
            "Rockwell Automation | Stratix 5700 IE1783-BMS06SA",
            "Rockwell Automation | Stratix 5700 IE1783-BMS06SGA",
            "Rockwell Automation | Stratix 5700 IE1783-BMS06SGL",
            "Rockwell Automation | Stratix 5700 IE1783-BMS06SL",
            "Rockwell Automation | Stratix 5700 IE1783-BMS06TA",
            "Rockwell Automation | Stratix 5700 IE1783-BMS06TGA",
            "Rockwell Automation | Stratix 5700 IE1783-BMS06TGL",
            "Rockwell Automation | Stratix 5700 IE1783-BMS06TL",
            "Rockwell Automation | Stratix 5700 IE1783-BMS10CA",
            "Rockwell Automation | Stratix 5700 IE1783-BMS10CGA",
            "Rockwell Automation | Stratix 5700 IE1783-BMS10CGL",
            "Rockwell Automation | Stratix 5700 IE1783-BMS10CGN",
            "Rockwell Automation | Stratix 5700 IE1783-BMS10CGP",
            "Rockwell Automation | Stratix 5700 IE1783-BMS10CL",
            "Rockwell Automation | Stratix 5700 IE1783-BMS12T4E2CGNK",
            "Rockwell Automation | Stratix 5700 IE1783-BMS20CA",
            "Rockwell Automation | Stratix 5700 IE1783-BMS20CGL",
            "Rockwell Automation | Stratix 5700 IE1783-BMS20CGN",
            "Rockwell Automation | Stratix 5700 IE1783-BMS20CGP",
            "Rockwell Automation | Stratix 5700 IE1783-BMS20CGPK",
            "Rockwell Automation | Stratix 5700 IE1783-BMS20CL",
            "Rockwell Automation | Stratix 8000 IE1783-MS06T",
            "Rockwell Automation | Stratix 8000 IE1783-MS10T",
            "Rockwell Automation | Stratix 8000 IE1783-RMS06T",
            "Rockwell Automation | Stratix 8000 IE1783-RMS10T",
            "SEIKO EPSON CORPORATION | OEM",
            "SNMP Research | Linux",
            "Sigma Network Systems | ELS10-26",
            "Sigma Network Systems | ELS10-27TX",
            "Sigma Network Systems | ELS10016TX",
            "Sigma Network Systems | OEM",
            "Stratacom | 8400 Stratacom",
            "Stratacom | OEM",
            "Symbol Technologies | Spectrum24 Ethernet Access Point",
            "SynOptics | 250 10/100 Hub",
            "SynOptics | 350-24T",
            "SynOptics | 350T-HD Switch",
            "SynOptics | 450-24T",
            "SynOptics | Bay Networks Inc., BayStack",
            "SynOptics | Bay Networks, Inc. BayStack",
            "SynOptics | BayStack",
            "SynOptics | BayStack 304 Ethernet Switch",
            "SynOptics | BayStack 410-24T",
            "SynOptics | BayStack 420 Switch",
            "SynOptics | BayStack 470 - 24T",
            "SynOptics | BayStack 470 - 48T",
            "SynOptics | Business Policy Switch",
            "SynOptics | Ethernet Routing Switch 5530-24TFD",
            "SynOptics | OEM",
            "SynOptics | Stack 150 Stackable Hub or",
            "SynOptics | Stack 202",
            "SynOptics | Token Ring Adv.",
            "Tec Corporation | OEM",
            "Technical University of Braunschweig | Linux",
            "Teklogix | 9150E Wireless Controller",
            "Teklogix | OEM",
            "Wellfleet | BayStack/Bay Network",
            "XLNT Networks | QuickEther-16 switch",
            "XLNT Networks | QuickFDDI+    switch",
            "Xlnt Designs  (XDI) | OEM",
            "Xylan Corp | Omni Switch/Router (5-slot)",
            "Xylan Corp | Omni Switch/Router (9-slot)",
            "Xylan Corp | OmniAccess 408",
            "Xylan Corp | OmniStack 1024",
            "Xylan Corp | OmniStack 4024G",
            "Xylan Corp | OmniStack 4024G/5024C",
            "Xylan Corp | OmniStack 5024",
            "Xylan Corp | OmniStack 6024",
            "Xylan Corp | OmniStack 6124",
            "Xylan Corp | OmniStack 6148",
            "ZyXEL Communications | OEM",
        ],
        "cmdb_ci_lb": [
            "Cisco Systems | ACE 10",
            "Cisco Systems | CD SCDE 200",
            "Cisco Systems | CE 507AV",
            "Cisco Systems | CE 510",
            "Cisco Systems | CE 560AV",
            "Cisco Systems | CE 566",
            "Cisco Systems | CE 611",
            "Cisco Systems | CE 674",
            "Cisco Systems | CE 7320",
            "Cisco Systems | CE 7341",
            "Cisco Systems | CSS 11506",
            "Cisco Systems | Local Director",
            "F5 Networks, Inc. | BIG-IP 10200S",
            "F5 Networks, Inc. | BIG-IP 10255",
            "F5 Networks, Inc. | BIG-IP Viprion B2100",
            "Radware | OEM",
            "Radware | Web Server Director Pro 2.x",
        ],
        "cmdb_ci_lb_ace": [
            "Cisco Systems | ACE 04G",
            "Cisco Systems | ACE 20K9",
            "Cisco Systems | ACE 30K9",
            "Cisco Systems | ACE 4710",
        ],
        "cmdb_ci_lb_bigip": [
            "F5 Networks, Inc. | BIG-IP",
            "F5 Networks, Inc. | BIG-IP",
            "F5 Networks, Inc. | BIG-IP 1000",
            "F5 Networks, Inc. | BIG-IP 10200",
            "F5 Networks, Inc. | BIG-IP 10200F",
            "F5 Networks, Inc. | BIG-IP 11000",
            "F5 Networks, Inc. | BIG-IP 11000F",
            "F5 Networks, Inc. | BIG-IP 11050",
            "F5 Networks, Inc. | BIG-IP 11050F",
            "F5 Networks, Inc. | BIG-IP 11050N",
            "F5 Networks, Inc. | BIG-IP 12050",
            "F5 Networks, Inc. | BIG-IP 1500",
            "F5 Networks, Inc. | BIG-IP 1600",
            "F5 Networks, Inc. | BIG-IP 2000",
            "F5 Networks, Inc. | BIG-IP 2200",
            "F5 Networks, Inc. | BIG-IP 2400",
            "F5 Networks, Inc. | BIG-IP 3400",
            "F5 Networks, Inc. | BIG-IP 3410",
            "F5 Networks, Inc. | BIG-IP 3600",
            "F5 Networks, Inc. | BIG-IP 3900",
            "F5 Networks, Inc. | BIG-IP 4000",
            "F5 Networks, Inc. | BIG-IP 4100",
            "F5 Networks, Inc. | BIG-IP 4200v",
            "F5 Networks, Inc. | BIG-IP 5000",
            "F5 Networks, Inc. | BIG-IP 5050",
            "F5 Networks, Inc. | BIG-IP 5100",
            "F5 Networks, Inc. | BIG-IP 5110",
            "F5 Networks, Inc. | BIG-IP 520",
            "F5 Networks, Inc. | BIG-IP 5200",
            "F5 Networks, Inc. | BIG-IP 5250",
            "F5 Networks, Inc. | BIG-IP 540",
            "F5 Networks, Inc. | BIG-IP 6400",
            "F5 Networks, Inc. | BIG-IP 6800",
            "F5 Networks, Inc. | BIG-IP 6900",
            "F5 Networks, Inc. | BIG-IP 6900F",
            "F5 Networks, Inc. | BIG-IP 6900N",
            "F5 Networks, Inc. | BIG-IP 6900S",
            "F5 Networks, Inc. | BIG-IP 7200",
            "F5 Networks, Inc. | BIG-IP 7200F",
            "F5 Networks, Inc. | BIG-IP 7200S",
            "F5 Networks, Inc. | BIG-IP 8400",
            "F5 Networks, Inc. | BIG-IP 8800",
            "F5 Networks, Inc. | BIG-IP 8900",
            "F5 Networks, Inc. | BIG-IP 8900F",
            "F5 Networks, Inc. | BIG-IP 8950",
            "F5 Networks, Inc. | BIG-IP 8950S",
            "F5 Networks, Inc. | BIG-IP EM4000",
            "F5 Networks, Inc. | BIG-IP PB100",
            "F5 Networks, Inc. | BIG-IP PB100N",
            "F5 Networks, Inc. | BIG-IP SAM4300",
            "F5 Networks, Inc. | BIG-IP vCMPGuest",
            "F5 Networks, Inc. | BIG-IP Viprion 4",
            "F5 Networks, Inc. | BIG-IP Viprion B2150",
            "F5 Networks, Inc. | BIG-IP Viprion B2250",
            "F5 Networks, Inc. | BIG-IP Viprion B4300",
            "F5 Networks, Inc. | BIG-IP Viprion C2400",
            "F5 Networks, Inc. | BIG-IP Virtual Edition",
            "F5 Networks, Inc. | OEM",
            "F5 Networks, Inc. | OEM",
        ],
        "cmdb_ci_lb_netscaler": ["Citrix | NetScaler"],
        "cmdb_ci_linux_server": [
            "Avaya | ACS48",
            "Cisco Systems | TANDBERG: Video Communication Server (VCS)",
            "ScienceLogic Environmental | EM7 P-Series Monitor",
            "ScienceLogic Environmental | OEM",
            "ScienceLogic | Integration Service",
            "ScienceLogic, Inc. | EM7 Admin Portal",
            "ScienceLogic, Inc. | EM7 All-In-One",
            "ScienceLogic, Inc. | EM7 Customer Portal",
            "ScienceLogic, Inc. | EM7 Data Collector",
            "ScienceLogic, Inc. | EM7 Database",
            "ScienceLogic, Inc. | EM7 G2 A1500 Application Server",
            "ScienceLogic, Inc. | EM7 G2 A2500 Application Server",
            "ScienceLogic, Inc. | EM7 G2 AIO E1500 Management System",
            "ScienceLogic, Inc. | EM7 G2 AIO Management System",
            "ScienceLogic, Inc. | EM7 G2 AIO Management System (Extended)",
            "ScienceLogic, Inc. | EM7 G2 Application Server",
            "ScienceLogic, Inc. | EM7 G2 C1500 Collection Server",
            "ScienceLogic, Inc. | EM7 G2 C2500 Collection Server",
            "ScienceLogic, Inc. | EM7 G2 C50 Collection Server",
            "ScienceLogic, Inc. | EM7 G2 C500 Collection Server",
            "ScienceLogic, Inc. | EM7 G2 Collection Server",
            "ScienceLogic, Inc. | EM7 G2 D2500 Enterprise Database",
            "ScienceLogic, Inc. | EM7 G2 D4500 Enterprise Database",
            "ScienceLogic, Inc. | EM7 G2 D6500 Enterprise Database",
            "ScienceLogic, Inc. | EM7 G2 Database",
            "ScienceLogic, Inc. | EM7 G2 E2500 Management System",
            "ScienceLogic, Inc. | EM7 G2 E4500 Management System",
            "ScienceLogic, Inc. | EM7 G2 E6500 Management System",
            "ScienceLogic, Inc. | EM7 Integration Server",
            "ScienceLogic, Inc. | EM7 Message Collector",
            "ScienceLogic, Inc. | OEM",
            "ScienceLogic, Inc. | SyncServer",
        ],
        "cmdb_ci_netgear": [
            "Cisco Systems | 1240",
            "Cisco Systems | AIR-WLC4400",
            "Cisco Systems | AP 1130",
            "Cisco Systems | BR 1300",
            "Cisco Systems | IDS IDSM-2",
            "Cisco Systems | IPS 4260",
            "Cisco Systems | IPS SSM-10",
            "Cisco Systems | MC3810-V3",
            "Cisco Systems | MDS 9020-20K9",
            "Telxon Corporation | Aironet 340 wireless bridge",
        ],
        "cmdb_ci_outofband_device": ["Dell | DRAC 1655MC"],
        "cmdb_ci_pdu": [
            "APC | MasterSwitch PDU",
            "APC | Web/SNMP Management Card",
            "APC | Web/SNMP Management Card+",
        ],
        "cmdb_ci_printer": [
            "Axis Communications | 540+/542+ Network Print Server",
            "Brother Industries, Ltd. | OEM",
            "CANON Inc. | Color Laser Beam Printer C",
            "CANON Inc. | Large Format W7250",
            "CANON Inc. | Network Multi-PDL Printer Board-",
            "CANON Inc. | OEM",
            "Castelle Corp. | OEM",
            "Dell | 5100cn",
            "Dell | OEM",
            "Electronics For Imaging, Inc. | Fiery Color Printer Server XJ+",
            "Electronics For Imaging, Inc. | Fiery Server Intel-VxWorks (GA-1",
            "Electronics For Imaging, Inc. | Fiery XP12/ZXPro MXPro",
            "Extended Systems, Inc. | (Print Server?)",
            "Extended Systems, Inc. | OEM",
            "Extended Systems, Inc. | TCP/IP PocketPrintServer",
            "Fuji Xerox Co., Ltd. | OEM",
            "H.Bollmann Manufacturers Ltd (HBM) | LAN Printer Interface XM AB1",
            "HP | HPNetwork Plotter",
            "HP | J2603A Hub",
            "HP | J3245A ProCurve Switch 800T",
            "HP | Jet-Direct Print Server (new ser",
            "HP | Jet-Direct Print Server (new ser",
            "HP | JetDirect J3113A",
            "HP | Network Printer",
            "HP | OEM",
            "IBM | 6252-T08 Impactwriter",
            "IBM | Infoprint Series",
            "IBM | InfoPrinter 40 Printer",
            "IBM | Network Printer 17",
            "IBM | Network Printer 24 (NP24)",
            "IBM | PrintNet Enterprise interface",
            "IBM | verion 4 (SP10?)",
            "Intel Corporation | NetportExpress(TM) PRO External",
            "Konica Minolta | OEM",
            "KYOCERA Corporation | Mita Printers (multi types)",
            "KYOCERA Corporation | OEM",
            "Lantronix | Lantronix",
            "Lantronix | MPS100 Label Printer",
            "Lantronix | MSS1",
            "Lantronix | MSS100 (Siemens AEM100)",
            "Lexmark International | OEM",
            "Lexmark International | Print Server",
            "Matsushita Electric Industrial Co., Ltd. | DocuColor 1632",
            "Matsushita Electric Industrial Co., Ltd. | DocuColor 2240",
            "Matsushita Electric Industrial Co., Ltd. | DP-4510 (also 3510)",
            "Matsushita Electric Industrial Co., Ltd. | OEM",
            "Microplex Systems Ltd. | NetPrint (OCE9300?)",
            "Oce Nederland BV | OEM",
            "Oki Data Corporation | 6100e",
            "Oki Data Corporation | OEM",
            "Oki Data Corporation | OKI OkiLAN 8100e Rev.02.15",
            "RICOH Co. Ltd. | EB-70 and Savin 9935DP/2",
            "RICOH Co. Ltd. | OEM",
            "Samsung Group | OEM",
            "Samsung Group | Samsung Network Printer",
            "SEIKO EPSON CORPORATION | Type-B 10Base-T/100Base-TX Print",
            "SHARP Corporation | AR-275",
            "SHARP Corporation | AR-505/S505",
            "SHARP Corporation | AR-M350",
            "SHARP Corporation | OEM",
            "Tektronix, Inc. | - Phaser 360 and 850DP",
            "Tektronix, Inc. | - Phaser 740 Printer",
            "Tektronix, Inc. | - Phaser 740EX Printer",
            "Tektronix, Inc. | - Phaser 750P",
            "Tektronix, Inc. | - Phaser 780GN Printer",
            "Tektronix, Inc. | - Phaser 840DX",
            "Tektronix, Inc. | - Phaser 860DP",
            "Tektronix, Inc. | - Phaser 860DX",
            "Tektronix, Inc. | - TekPhaser 350 Color laser",
            "Tektronix, Inc. | OEM",
            "Tektronix, Inc. | Phaser 7700DN/GX",
            "Tektronix, Inc. | Phaser 850DP",
            "Tektronix, Inc. | Phaser 850DX",
            "Tektronix, Inc. | Phaser 850N Color Printer",
            "Tektronix, Inc. | Phaser 860 N solid ink",
            "Tektronix, Inc. | Tektronix, Inc., Phaser 780P,",
            "Tektronix, Inc. | Tektronix, Inc., Phaser 8200DP,",
            "Tektronix, Inc. | Tektronix, Inc., Phaser 8200DX,",
            "UCD-SNMP | Darwin",
            "UCD-SNMP | FreeBSD",
            "UCD-SNMP | Macintosh",
            "Xerox | Document Center 230LP, v1.0",
            "Xerox | Document Center 230LP, v2.0",
            "Xerox | Document Center 230LP, v3.0",
            "Xerox | Document Center 230LP, v4.0",
            "Xerox | Document Center 230LP, v5.0",
            "Xerox | Document Center 230ST, v3.0",
            "Xerox | Document Center 230ST, v4.0",
            "Xerox | Document Center 230ST, v5.0",
            "Xerox | Document Center 240ST, v1.0",
            "Xerox | Document Center 240ST, v2.0",
            "Xerox | Document Center 240ST, v3.0",
            "Xerox | Document Center 265LP, v1.0",
            "Xerox | Document Center 265LP, v2.0",
            "Xerox | Document Center 265LP, v3.0",
            "Xerox | Document Center 265ST, v1.0",
            "Xerox | Document Center 265ST, v2.0",
            "Xerox | Document Center 265St, v3.0",
            "Xerox | Document Centre 220/230ST, v2.0",
            "Xerox | Document Centre 220/230ST, v3.0",
            "Xerox | Document Centre 230ST, v1.0",
            "Xerox | Document Centre 230ST, v1.0",
            "Xerox | Document Centre 230ST, v2.0",
            "Xerox | Document Centre 230ST, v3.0",
            "Xerox | Document Centre 255LP, v1.0",
            "Xerox | Document Centre 255LP, v2.0",
            "Xerox | Document Centre 255LP, v3.0",
            "Xerox | Document Centre 255ST, v1.0",
            "Xerox | Document Centre 255ST, v2.0",
            "Xerox | Document Centre 255ST, v3.0",
            "Xerox | Document Centre 332/340 ST, v1.0",
            "Xerox | Document Centre 332/340ST, v1.0",
            "Xerox | Document Centre 332LP, v1.0",
            "Xerox | Document Centre 332LP, v2.0",
            "Xerox | Document Centre 332LP, v3.0",
            "Xerox | Document Centre 332ST, v2.0",
            "Xerox | Document Centre 332ST, v3.0",
            "Xerox | Document Centre 340LP, v1.0",
            "Xerox | Document Centre 340LP, v2.0",
            "Xerox | Document Centre 340LP, v3.0",
            "Xerox | Document Centre 340ST, v2.0",
            "Xerox | Document Centre 340ST, v3.0",
            "Xerox | Document Centre 420ST, v1.0",
            "Xerox | Document Centre 420ST, v2.0",
            "Xerox | Document Centre 420ST, v3.0",
            "Xerox | Document Centre 425ST, v1.0",
            "Xerox | Document Centre 432ST, V1.0",
            "Xerox | Document Centre 432ST, V2.0",
            "Xerox | Document Centre 432ST, V3.0",
            "Xerox | Document Centre 440ST, v1.0",
            "Xerox | Document Centre 440ST, v2.0",
            "Xerox | Document Centre 440ST, v3.0",
            "Xerox | Document Centre 450, v1.0",
            "Xerox | Document Centre 450, v2.0",
            "Xerox | Document Centre 460, v1.0",
            "Xerox | Document Centre 460, v2.0",
            "Xerox | Document Centre 465, v1.0",
            "Xerox | Document Centre 465, v2.0",
            "Xerox | Document Centre 470, v1.0",
            "Xerox | Document Centre 470, v2.0",
            "Xerox | Document Centre 475, v1.0",
            "Xerox | Document Centre 475, v1.0",
            "Xerox | Document Centre 480, v1.0",
            "Xerox | Document Centre 480, v2.0",
            "Xerox | Document Centre 480, v3.0",
            "Xerox | Document Centre 485, v1.0",
            "Xerox | Document Centre 485, v2.0",
            "Xerox | Document Centre 495",
            "Xerox | Document Centre Centre 4110",
            "Xerox | Document Centre ColorSeries 50",
            "Xerox | Document Centre Multi-Function S",
            "Xerox | Docuprint 4512",
            "Xerox | DocuPrint N17",
            "Xerox | DocuPrint N2025, v1.0",
            "Xerox | DocuPrint N2025, v2.0",
            "Xerox | DocuPrint N2125, v1.0",
            "Xerox | DocuPrint N2125, v2.0",
            "Xerox | DocuPrint N24",
            "Xerox | DocuPrint N24/N32, v1.0",
            "Xerox | DocuPrint N24/N32, v2.0",
            "Xerox | DocuPrint N2825, v1.0",
            "Xerox | DocuPrint N2825, v2.0",
            "Xerox | DocuPrint N3225, v1.0",
            "Xerox | DocuPrint N3225, v2.0",
            "Xerox | Docuprint N40 Laser Printer",
            "Xerox | DocuPrint N4025, v1.0",
            "Xerox | DocuPrint N4025, v2.0",
            "Xerox | DocuPrint N4525",
            "Xerox | DocuPrint NC1235",
            "Xerox | DocuPrint NC60, v1.0",
            "Xerox | DocuPrint NC60, v2.0",
            "Xerox | DocuPrint NC60, v3.0",
            "Xerox | DocuTech 6180",
            "Xerox | OEM",
            "Xerox | Phaser 2135 Network Color Printe",
            "Xerox | Phaser 3400 Laser Printer",
            "Xerox | Phaser 6200 DP",
            "Xerox | Phaser 6200 DX",
            "Xerox | Phaser 7300 DN",
            "Xerox | WorkCentre Pro Multifunction Sys",
            "Xerox | Xerox Phaser 6350DP;PS 3.12.0,Ne",
            "Xerox | Xerox Phaser 7300 DT",
            "Xerox | Xerox Phaser 8400N;PS 16.76,Net",
            "Xerox | Xerox WorkCentre Pro Multifuncti",
        ],
        "cmdb_ci_storage_server": [
            "Dell EMC | Isilon Storage System",
            "NetApp | Cluster",
            "NetApp | Clustered Filer",
            "NetApp | Filer",
            "Network Appliance | FAS",
            "Network Appliance | FAS2020",
            "Network Appliance | FAS2050",
            "Network Appliance | FAS250",
            "Network Appliance | FAS270",
            "Network Appliance | FAS3020",
            "Network Appliance | FAS3040",
            "Network Appliance | FAS3070",
            "Network Appliance | FAS6040",
            "Network Appliance | FAS6070",
            "Network Appliance | FAS6080",
            "Network Appliance | FAS720",
            "Network Appliance | FAS740",
            "Network Appliance | FAS760",
            "Network Appliance | FAS810",
            "Network Appliance | FAS820",
            "Network Appliance | FAS820c",
            "Network Appliance | FAS825",
            "Network Appliance | FAS840",
            "Network Appliance | FAS840c",
            "Network Appliance | FAS87",
            "Network Appliance | FAS880",
            "Network Appliance | FAS920",
            "Network Appliance | FAS940",
            "Network Appliance | FAS940c",
            "Network Appliance | FAS960",
            "Network Appliance | FAS980",
            "Network Appliance | R150",
            "Network Appliance | R200",
        ],
        "cmdb_ci_ucs_equipment": [
            "Cisco Systems | UCS 6100",
            "Cisco Systems | UCS 6200",
            "Cisco Systems | UCS C200 Rack Server",
            "Cisco Systems | UCS C220 M4 Rack Server",
            "Cisco Systems | UCS C220 Rack Server",
            "Cisco Systems | UCS C240 M5",
            "Cisco Systems | UCS-FI-6248UP",
            "Cisco Systems | UCS-FI-6296UP",
            "Cisco Systems | UCS-FI-M6324",
        ],
        "cmdb_ci_unix_server": ["Santa Cruz Operation | TCP/IP Runtime Release 2.0.0"],
        "cmdb_ci_ups": [
            "APC | APC Web/SNMP Management Card",
            "APC | Embedded PowerNet SNMP Agent Mod",
            "APC | Environmental Monitor",
            "APC | OEM",
            "APC | SmartUPS 1000",
            "APC | SmartUPS 1250",
            "APC | SmartUPS 2000",
            "APC | SmartUPS 2200",
            "APC | SmartUPS 250",
            "APC | SmartUPS 3000",
            "APC | SmartUPS 400",
            "APC | SmartUPS 400/Liebert Series 300",
            "APC | SmartUPS 450",
            "APC | SmartUPS 600",
            "APC | SmartUPS 700",
            "APC | SmartUPS 900",
            "APC | UPS",
            "APC | Web/SNMP Management Card",
            "APC | Web/SNMP Management Card",
            "APC | Web/SNMP Management Card",
            "APC | Web/SNMP Management Card",
            "APC | Web/SNMP Management Card",
            "APC | Web/SNMP Management Card",
            "APC | Web/SNMP Management Card-RMS",
            "Exide Electronics | OEM",
            "Liebert | Npower",
            "Phoenixtec Power Co., Ltd. | OEM",
            "Powerware | 5130 RT 2200",
            "Powerware | 9125-5000g",
            "Powerware | 9355",
        ],
        "cmdb_ci_vcenter": ["VMware | vCenter", "VMWare | vCenter Server Appliance"],
        "cmdb_ci_vcenter_cluster": ["VMware | Cluster"],
        "cmdb_ci_vcenter_datacenter": ["VMware | Datacenter"],
        "cmdb_ci_vcenter_datastore": [
            "VMware | Datastore",
            "VMware | Datastore Cluster",
        ],
        "cmdb_ci_vcenter_dv_port_group": ["VMware | Distributed Virtual Portgroup"],
        "cmdb_ci_vcenter_dvs": ["VMware | Distributed Virtual Switch"],
        "cmdb_ci_vcenter_folder": ["VMware | Folder"],
        "cmdb_ci_vcenter_network": ["VMware | Network"],
        "cmdb_ci_vcenter_object": ["VMware | Virtual App"],
        "cmdb_ci_vmware_instance": ["VMware | Virtual Machine"],
        "cmdb_ci_win_server": [
            "Microsoft | Windows Server 2008",
            "Microsoft | Windows Server 2003",
            "Microsoft | Windows Server 2008 R2",
            "Microsoft | Windows Server",
            "Microsoft | Windows Server 2012",
            "Microsoft | Windows Server 2012 R2",
            "Microsoft | Windows Server 2016",
            "Microsoft | Windows Server 2019",
            "Microsoft | Windows Server 2008 Domain Controller",
            "Microsoft | Windows Server 2003 Domain Controller",
            "Microsoft | Windows Server 2012 Domain Controller",
            "Microsoft | Windows Server 2008 R2 Domain Controller",
            "Microsoft | Windows Server 2012 R2 Domain Controller",
            "Microsoft | Windows Server 2016 Domain Controller",
            "Microsoft | Windows Server 2019 Domain Controller",
        ],
    },
    description="The device class mappings to utilize for syncing.",
    required=True,
    sample_value={
        "cmdb_ci_linux_server": [
            "ScienceLogic, Inc. | EM7 All-In-One",
            "ScienceLogic, Inc. | SyncServer",
        ]
    },
    param_type=parameter_types.MappingParameterExternalOneToMany(
        left_url=SNOW_CI_CACHE,
        right_url=EM7_DEV_CLASS_CACHE,
        left_name="ServiceNow CI",
        right_name="SL1 Device Class",
    ),
)

ci_attrib_mappings_param = StepParameter(
    name=mappings_param.name,
    default_value=dict(),
    description="{} If blank, will use mappings from Device Sync.".format(
        mappings_param.description
    ),
    required=False,
    sample_value=mappings_param.sample_value,
    param_type=mappings_param.param_type,
)

org_filter_param = StepParameter(
    name="Include_Orgs",
    description="Device Filter: Inclusive list of Org IDs to Sync. Leave empty for All Orgs.",
    required=False,
    default_value=list(),
    param_type=parameter_types.ArrayParameterNumber(),
)

cug_filter_param = StepParameter(
    name="Include_CUGs",
    description="Device Filter: Inclusive list of Collector Group IDs to Sync. Leave empty for All Collector Groups.",
    required=False,
    default_value=list(),
    param_type=parameter_types.ArrayParameterNumber(),
)

sl1_url_override_param = StepParameter(
    name="sl1_url_override",
    default_value=str(),
    required=False,
    sample_value="em7.sciencelogic.com",
    description="Set this option to override the sl1_hostname value in "
    "ServiceNow CI properties.",
    param_type=parameter_types.StringParameterShort(),
)

service_request_in_progress_param = StepParameter(
    name="In_Progress_State",
    description="State for In Progress.",
    sample_value=3,
    default_value=2,
    required=True,
    param_type=parameter_types.NumberParameter(),
)

service_request_failed_param = StepParameter(
    name="Closed_Failed_State",
    description="State for un-successful run.",
    sample_value=3,
    default_value=4,
    required=True,
    param_type=parameter_types.NumberParameter(),
)
service_request_success_param = StepParameter(
    name="Closed_Success_State",
    description="State for successful run.",
    sample_value=3,
    default_value=3,
    required=True,
    param_type=parameter_types.NumberParameter(),
)
service_request_sys_id_param = StepParameter(
    name="sys_id",
    description="ServiceNow sys_id for RITM.",
    required=True,
    param_type=parameter_types.StringParameterShort(),
)
service_request_vcug_param = StepParameter(
    name="target_vcug",
    description="Target Virtual Collector Group for disabled devices.",
    required=False,
    default_value=None,
    param_type=parameter_types.NumberParameter(),
)
delete_device_vcug_param = StepParameter(
    name=service_request_vcug_param.name,
    default_value=-1,
    description="{} If -1, will use setting from Process Service Requests.".format(
        service_request_vcug_param.description
    ),
    required=service_request_vcug_param.required,
    param_type=service_request_vcug_param.param_type,
)
selected_devices_param = StepParameter(
    name="selected_devices",
    description="List of DIDs to Sync. Leave empty for full device sync.",
    required=False,
    default_value=list(),
    param_type=parameter_types.ArrayParameterNumber(),
)

domain_sep_param = StepParameter(
    name="Domain_Separation",
    description="Enable if Domain Separation is configured in ServiceNow. Forces Sending of Company sys_id.",
    required=False,
    default_value=False,
    param_type=parameter_types.BoolParameterToggle(),
)

drop_company_param = StepParameter(
    name="drop_company",
    description="Enable to drop Company sys_id from Device Payload. Has no effect if Domain Separation is enabled.",
    required=False,
    default_value=False,
    param_type=parameter_types.BoolParameterToggle(),
)

relation_overrides_param = StepParameter(
    name="customer_ci_relation_overrides",
    description="Customer specific CI Relation Overrides.",
    default_value={
        "cmdb_ci_esx_resource_pool": {
            "relations": [
                {
                    "parent": "cmdb_ci_esx_server",
                    "rel_type": "Registered on::Has registered",
                    "reverse": True,
                },
                {
                    "parent": "cmdb_ci_vcenter_cluster",
                    "rel_type": "Defines resources for::Gets resources from",
                    "reverse": True,
                },
            ],
            "values": {},
        },
        "cmdb_ci_esx_server": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter_cluster",
                    "rel_type": "Members::Member of",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Contains::Contained by",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_esx_resource_pool",
                    "rel_type": "Defines resources for::Get resources from",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_vcenter_datastore",
                    "rel_type": "Used by::Uses",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_vcenter_Network",
                    "rel_type": "Provided by::Provides",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_vmware_instance",
                    "rel_type": "Registered on::Has registered",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_vcenter",
                    "rel_type": "Runs on::Runs",
                    "reverse": False,
                },
            ],
            "values": {},
        },
        "cmdb_ci_ip_switch": {
            "relations": [
                {
                    "parent": "cmdb_ci_ip_switch",
                    "rel_type": "Connected by::Connects",
                    "reverse": False,
                }
            ],
            "values": {},
        },
        "cmdb_ci_vcenter_cluster": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Contains::Contained by",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_esx_server",
                    "rel_type": "Members::Members of",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_esx_resource_pool",
                    "rel_type": "Defines resources for::Get resources from",
                    "reverse": False,
                },
            ],
            "values": {},
        },
        "cmdb_ci_vcenter_datacenter": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter",
                    "rel_type": "Managed by::Manages",
                    "reverse": False,
                }
            ],
            "values": {},
        },
        "cmdb_ci_vcenter_datastore": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Contains::Contained by",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_vcenter_folder",
                    "rel_type": "Contains::Contained by",
                    "reverse": False,
                },
            ],
            "values": {},
        },
        "cmdb_ci_vcenter_dv_port_group": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Hosted on::Hosts",
                    "reverse": True,
                }
            ],
            "values": {},
        },
        "cmdb_ci_vcenter_dvs": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Hosted on::Hosts",
                    "reverse": True,
                }
            ],
            "values": {},
        },
        "cmdb_ci_vcenter_folder": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Hosted on::Hosts",
                    "reverse": True,
                }
            ],
            "values": {},
        },
        "cmdb_ci_vcenter_network": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Hosted on::Hosts",
                    "reverse": True,
                },
                {
                    "parent": "cmdb_ci_vmware_instance",
                    "rel_type": "Connected by::Connects",
                    "reverse": True,
                },
            ],
            "values": {},
        },
        "cmdb_ci_vcenter_object": {
            "relations": [
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Contains::Contained by",
                    "reverse": True,
                }
            ],
            "values": {},
        },
        "cmdb_ci_vmware_instance": {
            "relations": [
                {
                    "parent": "cmdb_ci_esx_server",
                    "rel_type": "Registered on::Has registered",
                    "reverse": True,
                },
                {
                    "parent": "cmdb_ci_vcenter_datacenter",
                    "rel_type": "Hosted on::Hosts",
                    "reverse": True,
                },
                {
                    "parent": "cmdb_ci_vcenter_folder",
                    "rel_type": "Contains::Contained by",
                    "reverse": False,
                },
                {
                    "parent": "cmdb_ci_vcenter_datastore",
                    "rel_type": "Provides storage for::Stored on",
                    "reverse": False,
                },
            ],
            "values": {},
        },
    },
    sample_value={
        "cmdb_ci_db_mssql_instance": {
            "relations": [
                {
                    "parent": "cmdb_ci_win_server",
                    "rel_type": "Runs on::Runs",
                    "reverse": True,
                }
            ],
            "values": {"sys_class_name": "snow_ci", "instance_name": "name"},
        }
    },
    required=False,
    param_type=parameter_types.JSONParameter(),
)

affected_ci_param = StepParameter(
    name="affected_cis",
    description="Affected CIs from Service Request.",
    required=False,
    default_value=list(),
    param_type=parameter_types.JSONParameter(),
)

org_attribute_mappings_param = StepParameter(
    name="attribute_mappings",
    description=(
        "Maps (Left Side) SL1 Org attributes to (Right Side) ServiceNow "
        "Company Attributes"
    ),
    required=False,
    default_value={
        "address": ["address"],
        "city": ["city"],
        "crm_id": ["sys_id", "crm_id"],
        "fax": ["fax"],
        "latitude": ["latitude"],
        "longitude": ["longitude"],
        "phone": ["phone"],
        "state": ["state"],
        "zip": ["zip"],
    },
    param_type=parameter_types.MappingParameterStaticOneToMany(
        left_name="SL1 Org Attributes",
        left_options=[
            "address",
            "billing_id",
            "city",
            "contact_fname",
            "contact_lname",
            "country",
            "crm_id",
            "dept",
            "email",
            "fax",
            "latitude",
            "longitude",
            "phone",
            "state",
            "title",
            "tollfree",
            "zip",
        ],
        right_name="ServiceNow Company Attributes",
        right_options=[
            "address",
            "city",
            "crm_id",
            "fax",
            "latitude",
            "longitude",
            "name",
            "phone",
            "state",
            "sys_id",
            "zip",
        ],
        custom=True,
    ),
)

exclude_inactive_param = StepParameter(
    name="exclude_inactive",
    description="Enable to Exclude devices from SL1 that are not in the Active state.",
    default_value=False,
    required=False,
    param_type=parameter_types.BoolParameterToggle(),
)


pf_host_param = StepParameter(
    name="pf_host",
    description="External Hostname/IP for PowerFlow Host.",
    required=True,
    sample_value="10.2.11.149",
    param_type=parameter_types.StringParameterShort(),
)


discovery_source_param = StepParameter(
    name="discovery_source",
    description="ServiceNow Discovery Source",
    default_value="Other Automated",
    required=True,
    sample_value="Other Automated",
    param_type=parameter_types.StringParameterShort(),
)
